#[non_exhaustive]pub struct CrossCert {
pub signature: CrossCertObject,
}Expand description
Pseudo-Signature of the long-term identity key by the medium-term key.
This type does not implement SignatureItemParseable because that trait
is reserved for signatures on netdocs, such as AuthCertSignature.
As CrossCert does not sign a full document, it implements only
ItemValueParseable, instead.
Verification of this signature is done in AuthCertUnverified::verify,
and during parsing by the old parser.
So a CrossCert in AuthCert::dir_key_crosscert in a bare AuthCert has been validated.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.signature: CrossCertObjectThe bytes of the signature (base64-decoded).
Implementations