EncodedAuthCert

Struct EncodedAuthCert 

pub struct EncodedAuthCert(/* private fields */);
Available on crate features parse2 and plain-consensus only.
Entire authority key certificate, encoded and signed

This is a newtype around String.

Invariants

  • Is a complete document in netdoc metasyntax including trailing newline.
  • Starts with one dir-key-certificate-version
  • Ends with one dir-key-certification
  • No other items are structural in a vote
  • Every item keyword starts dir- or is fingerprint

See https://spec.torproject.org/dir-spec/creating-key-certificates.html#nesting

Non-invariant

  • Signature and timeliness have not been checked.

Functionality

Implements TryFrom<String> and FromStr.

Implements NetdocParseable: parser matches dir-key-certificate-version and dir-key-certification, but also calls Bug if the caller’s stop_at reports that this keyword is structural for its container. (This could happen if an EncodedAuthCert existedd in some other document but a vote. We do not check this property during encoding.)

Rationale

Unlike most sub-documents found within netdocs, an authcert is a signed document. We expect to be able to copy an authcert into a vote, encode, convey and parse the vote, and extract the authcert, and verify the authcert’s signature.

Additionally, the fact that authcerts have their own signatures means that they need to be constructed separately from the surrounding document, and then embedded in it later.

When parsing a vote, we need to be able to see which parts are the authcert, and we need to be able to extract the specific document text, but we maybe don’t want to parse the authcert.

Conversely, signature verification of authcerts during decoding of a vote is fairly complex. We don’t want to do signature verification during parsing, because signature verification involves the time, and we don’t want parsing to need to know the time.

Implementations

Source

impl EncodedAuthCert

pub fn as_str(&self) -> &str

Obtain the document text as a str