pub struct ExtraInfoUnverified {
pub sigs: SignaturesData<ExtraInfoUnverified>,
/* private fields */
}Available on crate feature
incomplete only.Expand description
Signed (unverified) form of ExtraInfo
Embodies:
ExtraInfo: document bodyExtraInfoSignatures: signatures
If this type was parsed from a document text, the signatures have not yet been verified.
Use a .verify_... method to obtain useable, verified, contents.
Fields
sigs: SignaturesData<ExtraInfoUnverified>Signatures
Implementations
Sourceimpl ExtraInfoUnverified
impl ExtraInfoUnverified
Sourcepub fn verify(self, rd: &RouterDesc) -> Result<ExtraInfo, VerifyFailed>
pub fn verify(self, rd: &RouterDesc) -> Result<ExtraInfo, VerifyFailed>
Verifies an extra-info document.
This verification requires an already verified RouterDesc.
We do not work with time bounded values here, because all respective
time bounded values in extra-info documents match up with the respective
values in their associated RouterDesc. Instead, we simply require
RouterDesc to be timely for this to be timely as well.
For an extra-info document to be valid, the following constraints apply:
RouterDesc::routerimpliesExtraInfoIntroItem::nicknameRouterDesc::signing_keyimpliesExtraInfoIntroItem::fingerprintRouterDesc::identity_ed25519==ExtraInfo::identity_ed25519RouterDesc::published==ExtraInfo::publishedRouterDesc::extra_info_digestimplies this document.- This document has valid signatures.