pub struct Microdesc {
pub onion_key: MicrodescIntroItem,
pub ntor_onion_key: Curve25519Public,
pub family: Intern<RelayFamily>,
pub family_ids: RelayFamilyIds,
pub ipv4_policy: Intern<PortPolicy>,
pub ipv6_policy: Intern<PortPolicy>,
pub ed25519_id: Ed25519IdentityLine,
/* private fields */
}Expand description
A single microdescriptor.
https://spec.torproject.org/dir-spec/computing-microdescriptors.html
Fields
onion_key: MicrodescIntroItemThe legacy onion key, whose object is optional but whose item serves as the intro line for these kind of descriptors.
ntor_onion_key: Curve25519PublicPublic key used for the ntor circuit extension protocol.
family: Intern<RelayFamily>Declared family for this relay.
family_ids: RelayFamilyIdsFamily identities for this relay.
ipv4_policy: Intern<PortPolicy>List of IPv4 ports to which this relay will exit
ipv6_policy: Intern<PortPolicy>List of IPv6 ports to which this relay will exit
ed25519_id: Ed25519IdentityLineEd25519 identity for this relay
Implementations
Sourceimpl Microdesc
impl Microdesc
Sourcepub fn ipv4_policy(&self) -> &Intern<PortPolicy>
pub fn ipv4_policy(&self) -> &Intern<PortPolicy>
Return the ipv4 exit policy for this microdesc
Sourcepub fn ipv6_policy(&self) -> &Intern<PortPolicy>
pub fn ipv6_policy(&self) -> &Intern<PortPolicy>
Return the ipv6 exit policy for this microdesc
Sourcepub fn family(&self) -> &RelayFamily
pub fn family(&self) -> &RelayFamily
Return the relay family for this microdesc
Sourcepub fn ed25519_id(&self) -> &Ed25519Identity
pub fn ed25519_id(&self) -> &Ed25519Identity
Return the ed25519 identity for this microdesc, if its Ed25519 identity is well-formed.
Sourcepub fn family_ids(&self) -> &[RelayFamilyId]
pub fn family_ids(&self) -> &[RelayFamilyId]
Return a list of family ids for this microdesc.