#[non_exhaustive]pub struct MicrodescAndHash {
pub md: Microdesc,
pub sha256: MdDigest,
}Expand description
A single microdescriptor and also its SHA256 hash
API compatibility type.
This type is only generated when the microdescriptor is parsed
using the old parser (MicrodescAndHash::parse)
rather than the new one
(Microdesc as NetdocParseable).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.md: MicrodescThe microdescriptor
sha256: MdDigestThe SHA256 digest of the text of this microdescriptor.
This value is used to identify the microdescriptor when downloading it, and when listing it in a consensus document.
Implementations
Sourceimpl MicrodescAndHash
impl MicrodescAndHash
Sourcepub fn builder() -> MicrodescBuilder
Available on crate feature build_docs only.
pub fn builder() -> MicrodescBuilder
build_docs only.Create a new MicrodescBuilder that can be used to construct microdescriptors.
This function is only available when the crate is built with the
build_docs feature.
Limitations
The generated microdescriptors cannot yet be encoded, and do not yet have correct sha256 digests. As such they are only useful for testing.
Sourceimpl MicrodescAndHash
impl MicrodescAndHash
Sourcepub fn parse(s: &str) -> Result<MicrodescAndHash>
pub fn parse(s: &str) -> Result<MicrodescAndHash>
Parse a string into a new microdescriptor.
Methods from Deref<Target = Microdesc>
Sourcepub fn ipv4_policy(&self) -> &Intern<PortPolicy>
pub fn ipv4_policy(&self) -> &Intern<PortPolicy>
Return the ipv4 exit policy for this microdesc
Sourcepub fn ipv6_policy(&self) -> &Intern<PortPolicy>
pub fn ipv6_policy(&self) -> &Intern<PortPolicy>
Return the ipv6 exit policy for this microdesc
Sourcepub fn family(&self) -> &RelayFamily
pub fn family(&self) -> &RelayFamily
Return the relay family for this microdesc
Sourcepub fn ed25519_id(&self) -> &Ed25519Identity
pub fn ed25519_id(&self) -> &Ed25519Identity
Return the ed25519 identity for this microdesc, if its Ed25519 identity is well-formed.
Sourcepub fn family_ids(&self) -> &[RelayFamilyId]
pub fn family_ids(&self) -> &[RelayFamilyId]
Return a list of family ids for this microdesc.