pub struct MicrodescConstructor {
pub ntor_onion_key: Curve25519Public,
pub ed25519_id: Ed25519IdentityLine,
}Expand description
Constructor (required fields) for Microdesc
See Microdesc.
This constructor struct contains precisely the required fields.
You can make a Microdesc out of it with .construct(),
or the From impl,
and use the result as a basis for further modifications.
Example
ⓘ
let microdesc = Microdesc {
onion_key: /* optional field value */,
family: /* optional field value */,
family_ids: /* optional field value */,
ipv4_policy: /* optional field value */,
ipv6_policy: /* optional field value */,
__non_exhaustive: /* optional field value */,
..MicrodescConstructor {
ntor_onion_key: /* required field value */,
ed25519_id: /* required field value */,
}.construct()
};Fields
ntor_onion_key: Curve25519PublicPublic key used for the ntor circuit extension protocol.
ed25519_id: Ed25519IdentityLineEd25519 identity for this relay
Implementations