pub struct MicrodescIntroItem(/* private fields */);Expand description
Intro line for a Microdesc.
The object (the onion key) is deprecated and optional, but the item itself must be present, because it is used to mark the start of the netdoc.
The object is private to prevent interfacing applications from generating microdesc’s with an onion-key; they are not necessary anymore and just waste space.