#[non_exhaustive]pub enum ConsensusVerifiabilityError {
InsufficientTrustedSigners,
MissingAuthCerts {
deficit: usize,
missing: HashSet<AuthCertKeyIds>,
},
}Expand description
Error which will prevent us from attempting to verify signatures on a consensus
This error occurs if we the consensus isn’t signed by the right people, or we are lacking authcerts.
Does not represent actual verification errors.
Those show up as VerifyFailed, typically ConsensusVerifyFailed::InvalidSignature.
Can be converted to a VerifyFailed,
giving InsufficientTrustedSigners.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InsufficientTrustedSigners
Insufficient trusted signers
MissingAuthCerts
Insufficient trusted signers because we are missing authcerts
Fields

missing: HashSet<AuthCertKeyIds>All the authcerts that would be useful