pub struct NetworkStatus {
pub network_status_version: NetworkStatusVersionItem,
pub vote_status: VoteStatusConsensus,
pub preamble: Preamble,
pub authority: ConsensusAuthoritySection,
pub routers: Vec<RouterStatus>,
pub footer: Footer,
/* private fields */
}Available on crate feature
incomplete only.Expand description
Network status document - consensus, or vote
https://spec.torproject.org/dir-spec/consensus-formats.html
https://spec.torproject.org/dir-spec/computing-consensus.html#flavors
Fields
network_status_version: NetworkStatusVersionItemThe network-status-version intro item
https://spec.torproject.org/dir-spec/consensus-formats.html#item:network-status-version
In the “preamble” in the spec, but not in our Preamble type for Reasons.
vote_status: VoteStatusConsensusvote-status
https://spec.torproject.org/dir-spec/consensus-formats.html#item:vote-status
In the “preamble” in the spec, but not in our Preamble type for Reasons.
preamble: PreambleThe rest of the preamble
https://spec.torproject.org/dir-spec/consensus-formats.html#section:preable
routers: Vec<RouterStatus>Router status entries
https://spec.torproject.org/dir-spec/consensus-formats.html#section:router-status