pub struct VarietyKeyword;Expand description
The optional ns keyword in a plain consensus heading line
This type is one of the fields in NetworkStatusVersionItem.
plain consensuses start with network-status-version 3 ns ...,
or are just network-status-version 3.
C Tor doesn’t emit ns, but we will.
In our terminology this is a plain consensus, in but the protocol it’s ns.
So in this variety, we parse as an optional fixed string ns,
and encode as (always) the string ns.
See also torspec#359