pub struct ConsensusAuthorityEntry {
pub dir_source: DirSource,
pub contact: ContactInfo,
pub vote_digest: B16U,
/* private fields */
}Expand description
An authority entry as found in a consensus
https://spec.torproject.org/dir-spec/consensus-formats.html#section:authority-entry
See also VoteAuthorityEntry
Fields
dir_source: DirSourceContents of the dir-source line about an authority
contact: ContactInfoHuman-readable contact information about the authority
vote_digest: B16UDigest of the vote that the authority cast to contribute to this consensus.
This is not a fixed-length, fixed-algorithm field. Bizarrely, the algorithm is supposed to be inferred from the length! https://spec.torproject.org/dir-spec/consensus-formats.html#item:vote-digest