ConsensusAuthorityEntryConstructor

Struct ConsensusAuthorityEntryConstructor 

pub struct ConsensusAuthorityEntryConstructor {
    pub dir_source: DirSource,
    pub contact: ContactInfo,
    pub vote_digest: B16U,
}
Constructor (required fields) for ConsensusAuthorityEntry

See ConsensusAuthorityEntry.

This constructor struct contains precisely the required fields. You can make a ConsensusAuthorityEntry out of it with .construct(), or the From impl, and use the result as a basis for further modifications.

Example

let consensus_authority_entry = ConsensusAuthorityEntry {
    __non_exhaustive: /* optional field value */,
    ..ConsensusAuthorityEntryConstructor {
        dir_source: /* required field value */,
        contact: /* required field value */,
        vote_digest: /* required field value */,
    }.construct()
};

Fields

dir_source: DirSource

Contents of the dir-source line about an authority

contact: ContactInfo

Human-readable contact information about the authority

vote_digest: B16U

Digest of the vote that the authority cast to contribute to this consensus.

This is not a fixed-length, fixed-algorithm field. Bizarrely, the algorithm is supposed to be inferred from the length! https://spec.torproject.org/dir-spec/consensus-formats.html#item:vote-digest

Implementations

Source

impl ConsensusAuthorityEntryConstructor

pub fn construct(self) -> ConsensusAuthorityEntry

Construct a minimal ConsensusAuthorityEntry

In the returned ConsensusAuthorityEntry, optional fields all get the default values.