pub struct ConsensusAuthoritySection {
pub authorities: Vec<ConsensusAuthorityEntry>,
pub superseded_keys: Vec<SupersededAuthorityKey>,
/* private fields */
}Expand description
Authority section as found in a consensus
https://spec.torproject.org/dir-spec/consensus-formats.html#section:authority
Note that though you can construct one with an empty authorities field,
that will generate a Bug when you encode it.
For votes, see VoteAuthoritySection
Fields
Authority entries
Always nonempty when parsed; must be nonempty or encoding will fail with Bug.
superseded_keys: Vec<SupersededAuthorityKey>Superseded authority key entries