pub struct DirSource {
pub nickname: Nickname,
pub identity: Fingerprint,
pub hostname: InternetHost,
pub ip: IpAddr,
pub dir_port: u16,
pub or_port: u16,
/* private fields */
}Expand description
Description of an authority’s identity and address.
Corresponds to a dir-source line which is not a “superseded authority key entry”. https://spec.torproject.org/dir-spec/consensus-formats.html#item:dir-source
Fields
nickname: Nicknamehuman-readable nickname for this authority.
identity: FingerprintFingerprint for the authority identity key of this authority.
This is the same key as the one that signs the authority’s certificates.
hostname: InternetHostIP address for the authority
ip: IpAddrIP address for the authority
dir_port: u16HTTP directory port for this authority
or_port: u16OR port for this authority.