pub struct LifetimeConstructor {
pub valid_after: Iso8601TimeSp,
pub fresh_until: Iso8601TimeSp,
pub valid_until: Iso8601TimeSp,
}Expand description
Constructor (required fields) for Lifetime
See Lifetime.
This constructor struct contains precisely the required fields.
You can make a Lifetime out of it with .construct(),
or the From impl,
and use the result as a basis for further modifications.
Example
let lifetime = Lifetime {
__non_exhaustive: /* optional field value */,
..LifetimeConstructor {
valid_after: /* required field value */,
fresh_until: /* required field value */,
valid_until: /* required field value */,
}.construct()
};Fields
valid_after: Iso8601TimeSpvalid-after — Time at which the document becomes valid
https://spec.torproject.org/dir-spec/consensus-formats.html#item:published
(You might see a consensus a little while before this time, since voting tries to finish up before the.)
fresh_until: Iso8601TimeSpfresh-until — Time after which there is expected to be a better version
of this consensus
https://spec.torproject.org/dir-spec/consensus-formats.html#item:published
You can use the consensus after this time, but there is (or is supposed to be) a better one by this point.
valid_until: Iso8601TimeSpvalid-until — Time after which this consensus is expired.
https://spec.torproject.org/dir-spec/consensus-formats.html#item:published
You should try to get a better consensus after this time, though it’s okay to keep using this one if no more recent one can be found.
Implementations