pub struct RecommendedTorVersions(/* private fields */);Expand description
List of recommended Tor versions
As seen in client-versions and server-versions in the preamble.
Technically these are supposed to be as according to
“version-spec.txt” but we actually allow anything that doesn’t contain commas.
https://spec.torproject.org/dir-spec/consensus-formats.html#item:client-versions https://spec.torproject.org/dir-spec/consensus-formats.html#item:server-versions
An empty set means no information, not no recommended versions.
Implementations
Sourceimpl RecommendedTorVersions
impl RecommendedTorVersions
Sourcepub fn new_unknown() -> Self
pub fn new_unknown() -> Self
Return a RecommendedTorVersions that has no information
Sourcepub fn is_known(&self) -> bool
pub fn is_known(&self) -> bool
Does this RecommendedTorVersions have any information?
Ie, is it not empty.
The opposite of BTreeSet::is_empty() (which available via deref).
Sourcepub fn from_iter<I, S>(i: I) -> Result<Self, InvalidRecommendedTorVersions>
pub fn from_iter<I, S>(i: I) -> Result<Self, InvalidRecommendedTorVersions>
Construct a RecommendedTorVersions from a list of strings
Methods from Deref<Target = BTreeSet<String>>
1.17.0 · Sourcepub fn range<K, R>(&self, range: R) -> Range<'_, T>
pub fn range<K, R>(&self, range: R) -> Range<'_, T>
Constructs a double-ended iterator over a sub-range of elements in the set.
The simplest way is to use the range syntax min..max, thus range(min..max) will
yield elements from min (inclusive) to max (exclusive).
The range may also be entered as (Bound<T>, Bound<T>), so for example
range((Excluded(4), Included(10))) will yield a left-exclusive, right-inclusive
range from 4 to 10.
Panics
Panics if range start > end.
Panics if range start == end and both bounds are Excluded.
Examples
use std::collections::BTreeSet;
use std::ops::Bound::Included;
let mut set = BTreeSet::new();
set.insert(3);
set.insert(5);
set.insert(8);
for &elem in set.range((Included(&4), Included(&8))) {
println!("{elem}");
}
assert_eq!(Some(&5), set.range(4..).next());1.0.0 · Sourcepub fn difference<'a>(
&'a self,
other: &'a BTreeSet<T, A>,
) -> Difference<'a, T, A>where
T: Ord,
pub fn difference<'a>(
&'a self,
other: &'a BTreeSet<T, A>,
) -> Difference<'a, T, A>where
T: Ord,
Visits the elements representing the difference,
i.e., the elements that are in self but not in other,
in ascending order.
Examples
use std::collections::BTreeSet;
let mut a = BTreeSet::new();
a.insert(1);
a.insert(2);
let mut b = BTreeSet::new();
b.insert(2);
b.insert(3);
let diff: Vec<_> = a.difference(&b).cloned().collect();
assert_eq!(diff, [1]);1.0.0 · Sourcepub fn symmetric_difference<'a>(
&'a self,
other: &'a BTreeSet<T, A>,
) -> SymmetricDifference<'a, T>where
T: Ord,
pub fn symmetric_difference<'a>(
&'a self,
other: &'a BTreeSet<T, A>,
) -> SymmetricDifference<'a, T>where
T: Ord,
Visits the elements representing the symmetric difference,
i.e., the elements that are in self or in other but not in both,
in ascending order.
Examples
use std::collections::BTreeSet;
let mut a = BTreeSet::new();
a.insert(1);
a.insert(2);
let mut b = BTreeSet::new();
b.insert(2);
b.insert(3);
let sym_diff: Vec<_> = a.symmetric_difference(&b).cloned().collect();
assert_eq!(sym_diff, [1, 3]);1.0.0 · Sourcepub fn intersection<'a>(
&'a self,
other: &'a BTreeSet<T, A>,
) -> Intersection<'a, T, A>where
T: Ord,
pub fn intersection<'a>(
&'a self,
other: &'a BTreeSet<T, A>,
) -> Intersection<'a, T, A>where
T: Ord,
Visits the elements representing the intersection,
i.e., the elements that are both in self and other,
in ascending order.
Examples
use std::collections::BTreeSet;
let mut a = BTreeSet::new();
a.insert(1);
a.insert(2);
let mut b = BTreeSet::new();
b.insert(2);
b.insert(3);
let intersection: Vec<_> = a.intersection(&b).cloned().collect();
assert_eq!(intersection, [2]);1.0.0 · Sourcepub fn union<'a>(&'a self, other: &'a BTreeSet<T, A>) -> Union<'a, T>where
T: Ord,
pub fn union<'a>(&'a self, other: &'a BTreeSet<T, A>) -> Union<'a, T>where
T: Ord,
Visits the elements representing the union,
i.e., all the elements in self or other, without duplicates,
in ascending order.
Examples
use std::collections::BTreeSet;
let mut a = BTreeSet::new();
a.insert(1);
let mut b = BTreeSet::new();
b.insert(2);
let union: Vec<_> = a.union(&b).cloned().collect();
assert_eq!(union, [1, 2]);1.0.0 · Sourcepub fn contains<Q>(&self, value: &Q) -> bool
pub fn contains<Q>(&self, value: &Q) -> bool
Returns true if the set contains an element equal to the value.
The value may be any borrowed form of the set’s element type, but the ordering on the borrowed form must match the ordering on the element type.
Examples
use std::collections::BTreeSet;
let set = BTreeSet::from([1, 2, 3]);
assert_eq!(set.contains(&1), true);
assert_eq!(set.contains(&4), false);1.9.0 · Sourcepub fn get<Q>(&self, value: &Q) -> Option<&T>
pub fn get<Q>(&self, value: &Q) -> Option<&T>
Returns a reference to the element in the set, if any, that is equal to the value.
The value may be any borrowed form of the set’s element type, but the ordering on the borrowed form must match the ordering on the element type.
Examples
use std::collections::BTreeSet;
let set = BTreeSet::from([1, 2, 3]);
assert_eq!(set.get(&2), Some(&2));
assert_eq!(set.get(&4), None);1.0.0 · Sourcepub fn is_disjoint(&self, other: &BTreeSet<T, A>) -> boolwhere
T: Ord,
pub fn is_disjoint(&self, other: &BTreeSet<T, A>) -> boolwhere
T: Ord,
Returns true if self has no elements in common with other.
This is equivalent to checking for an empty intersection.
Examples
use std::collections::BTreeSet;
let a = BTreeSet::from([1, 2, 3]);
let mut b = BTreeSet::new();
assert_eq!(a.is_disjoint(&b), true);
b.insert(4);
assert_eq!(a.is_disjoint(&b), true);
b.insert(1);
assert_eq!(a.is_disjoint(&b), false);1.0.0 · Sourcepub fn is_subset(&self, other: &BTreeSet<T, A>) -> boolwhere
T: Ord,
pub fn is_subset(&self, other: &BTreeSet<T, A>) -> boolwhere
T: Ord,
Returns true if the set is a subset of another,
i.e., other contains at least all the elements in self.
Examples
use std::collections::BTreeSet;
let sup = BTreeSet::from([1, 2, 3]);
let mut set = BTreeSet::new();
assert_eq!(set.is_subset(&sup), true);
set.insert(2);
assert_eq!(set.is_subset(&sup), true);
set.insert(4);
assert_eq!(set.is_subset(&sup), false);1.0.0 · Sourcepub fn is_superset(&self, other: &BTreeSet<T, A>) -> boolwhere
T: Ord,
pub fn is_superset(&self, other: &BTreeSet<T, A>) -> boolwhere
T: Ord,
Returns true if the set is a superset of another,
i.e., self contains at least all the elements in other.
Examples
use std::collections::BTreeSet;
let sub = BTreeSet::from([1, 2]);
let mut set = BTreeSet::new();
assert_eq!(set.is_superset(&sub), false);
set.insert(0);
set.insert(1);
assert_eq!(set.is_superset(&sub), false);
set.insert(2);
assert_eq!(set.is_superset(&sub), true);1.66.0 · Sourcepub fn first(&self) -> Option<&T>where
T: Ord,
pub fn first(&self) -> Option<&T>where
T: Ord,
Returns a reference to the first element in the set, if any. This element is always the minimum of all elements in the set.
Examples
Basic usage:
use std::collections::BTreeSet;
let mut set = BTreeSet::new();
assert_eq!(set.first(), None);
set.insert(1);
assert_eq!(set.first(), Some(&1));
set.insert(2);
assert_eq!(set.first(), Some(&1));1.66.0 · Sourcepub fn last(&self) -> Option<&T>where
T: Ord,
pub fn last(&self) -> Option<&T>where
T: Ord,
Returns a reference to the last element in the set, if any. This element is always the maximum of all elements in the set.
Examples
Basic usage:
use std::collections::BTreeSet;
let mut set = BTreeSet::new();
assert_eq!(set.last(), None);
set.insert(1);
assert_eq!(set.last(), Some(&1));
set.insert(2);
assert_eq!(set.last(), Some(&2));1.0.0 · Sourcepub fn iter(&self) -> Iter<'_, T>
pub fn iter(&self) -> Iter<'_, T>
Gets an iterator that visits the elements in the BTreeSet in ascending
order.
Examples
use std::collections::BTreeSet;
let set = BTreeSet::from([3, 1, 2]);
let mut set_iter = set.iter();
assert_eq!(set_iter.next(), Some(&1));
assert_eq!(set_iter.next(), Some(&2));
assert_eq!(set_iter.next(), Some(&3));
assert_eq!(set_iter.next(), None);1.0.0 · Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of elements in the set.
Examples
use std::collections::BTreeSet;
let mut v = BTreeSet::new();
assert_eq!(v.len(), 0);
v.insert(1);
assert_eq!(v.len(), 1);1.0.0 · Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the set contains no elements.
Examples
use std::collections::BTreeSet;
let mut v = BTreeSet::new();
assert!(v.is_empty());
v.insert(1);
assert!(!v.is_empty());Sourcepub fn lower_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, T>
🔬This is a nightly-only experimental API. (btree_cursors)
pub fn lower_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, T>
btree_cursors)Returns a Cursor pointing at the gap before the smallest element
greater than the given bound.
Passing Bound::Included(x) will return a cursor pointing to the
gap before the smallest element greater than or equal to x.
Passing Bound::Excluded(x) will return a cursor pointing to the
gap before the smallest element greater than x.
Passing Bound::Unbounded will return a cursor pointing to the
gap before the smallest element in the set.
Examples
#![feature(btree_cursors)]
use std::collections::BTreeSet;
use std::ops::Bound;
let set = BTreeSet::from([1, 2, 3, 4]);
let cursor = set.lower_bound(Bound::Included(&2));
assert_eq!(cursor.peek_prev(), Some(&1));
assert_eq!(cursor.peek_next(), Some(&2));
let cursor = set.lower_bound(Bound::Excluded(&2));
assert_eq!(cursor.peek_prev(), Some(&2));
assert_eq!(cursor.peek_next(), Some(&3));
let cursor = set.lower_bound(Bound::Unbounded);
assert_eq!(cursor.peek_prev(), None);
assert_eq!(cursor.peek_next(), Some(&1));Sourcepub fn upper_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, T>
🔬This is a nightly-only experimental API. (btree_cursors)
pub fn upper_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, T>
btree_cursors)Returns a Cursor pointing at the gap after the greatest element
smaller than the given bound.
Passing Bound::Included(x) will return a cursor pointing to the
gap after the greatest element smaller than or equal to x.
Passing Bound::Excluded(x) will return a cursor pointing to the
gap after the greatest element smaller than x.
Passing Bound::Unbounded will return a cursor pointing to the
gap after the greatest element in the set.
Examples
#![feature(btree_cursors)]
use std::collections::BTreeSet;
use std::ops::Bound;
let set = BTreeSet::from([1, 2, 3, 4]);
let cursor = set.upper_bound(Bound::Included(&3));
assert_eq!(cursor.peek_prev(), Some(&3));
assert_eq!(cursor.peek_next(), Some(&4));
let cursor = set.upper_bound(Bound::Excluded(&3));
assert_eq!(cursor.peek_prev(), Some(&2));
assert_eq!(cursor.peek_next(), Some(&3));
let cursor = set.upper_bound(Bound::Unbounded);
assert_eq!(cursor.peek_prev(), Some(&4));
assert_eq!(cursor.peek_next(), None);Trait Implementations
Sourceimpl Clone for RecommendedTorVersions
impl Clone for RecommendedTorVersions
Sourcefn clone(&self) -> RecommendedTorVersions
fn clone(&self) -> RecommendedTorVersions
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RecommendedTorVersions
impl Debug for RecommendedTorVersions
Sourceimpl Default for RecommendedTorVersions
impl Default for RecommendedTorVersions
Sourcefn default() -> RecommendedTorVersions
fn default() -> RecommendedTorVersions
Sourceimpl Deref for RecommendedTorVersions
impl Deref for RecommendedTorVersions
Sourceimpl Display for RecommendedTorVersions
impl Display for RecommendedTorVersions
impl Eq for RecommendedTorVersions
Sourceimpl From<RecommendedTorVersions> for BTreeSet<String>
impl From<RecommendedTorVersions> for BTreeSet<String>
Sourcefn from(value: RecommendedTorVersions) -> Self
fn from(value: RecommendedTorVersions) -> Self
Sourceimpl FromStr for RecommendedTorVersions
impl FromStr for RecommendedTorVersions
Sourceimpl ItemValueEncodable for RecommendedTorVersions
impl ItemValueEncodable for RecommendedTorVersions
Sourcefn write_item_value_onto(&self, out: ItemEncoder<'_>) -> Result<(), Bug>
fn write_item_value_onto(&self, out: ItemEncoder<'_>) -> Result<(), Bug>
out Read moreSourceimpl ItemValueParseable for RecommendedTorVersions
impl ItemValueParseable for RecommendedTorVersions
Sourcefn from_unparsed(item: UnparsedItem<'_>) -> Result<Self, ErrorProblem>
fn from_unparsed(item: UnparsedItem<'_>) -> Result<Self, ErrorProblem>
impl NormalItemArgument for RecommendedTorVersions
Sourceimpl Ord for RecommendedTorVersions
impl Ord for RecommendedTorVersions
Sourcefn cmp(&self, other: &RecommendedTorVersions) -> Ordering
fn cmp(&self, other: &RecommendedTorVersions) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for RecommendedTorVersions
impl PartialEq for RecommendedTorVersions
Sourcefn eq(&self, other: &RecommendedTorVersions) -> bool
fn eq(&self, other: &RecommendedTorVersions) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RecommendedTorVersions
impl PartialOrd for RecommendedTorVersions
impl StructuralPartialEq for RecommendedTorVersions