RelayWeightsItem

Struct RelayWeightsItem 

pub struct RelayWeightsItem { /* private fields */ }
Relay weight information - w item in routerstatus

This is a combination of two representations of (subsets of) the same information, from an optional w in the document.

  • effective:

    Always contains the effective weight, as RelayWeight. This is what is used by clients. It does not record whether a w line was actually present.

  • params:

    Can represent the presence and whole contents of the w line, including all the known and unknown parameters. This is within Unknown, so it is only present with crate feature = "retain-unknown", and only some constructors/parsers record it.

Parsing

Parsing is done with NetdocParseableFields rather than ItemValueParseable. The params are Retained if retain_unknown_values is selected in parse2::ParseOptions.

Encoding

Encoding requires knowing whether a w line is to be included, and its contents, so is implemented only with if effective is Unknown::Retained. The encoding impl is only compiled in with "retain-unknown", and throws Bug if applied to a RelayWeightsItem whose params are Discarded.

Constructors

An “empty” RelayWeightsItem can be constructed with RelayWeightsItem::new_no_info.

A RelayWeightsItem containing only the effective RelayWeight can be constructed using RelayWeightsItem::from_effective.

With "retain-unknown": a RelayWeightsItem can be constructed from a NetParams<u32> using TryFrom; and, implements Default, which yields a RelayWeightsItem representing the (known) absence of a w line.

Implementations

Source

impl RelayWeightsItem

pub fn new_no_info() -> Self

Return a new RelayWeightsItem containing no information

As if parsed from a document with no w line, discarding unknown information.

pub fn from_effective(effective: RelayWeight) -> Self

Return a new RelayWeightsItem containing only the effective weight

pub fn effective(&self) -> RelayWeight

Get the effective relay weight (bandwidth estimate) for path selection.

Invariant: consistent with from params, if parsed isn’t Discarded.

pub fn params(&self) -> Unknown<&Option<NetParams<u32>>>

Get the complete parameter set, if this information is available.

After parsing, this is the parsed but not interpreted w item, or None if the document contained no w item.