#[non_exhaustive]pub struct SignatureGroup {
pub hashes: DirectorySignaturesHashesAccu,
pub signatures: Vec<Signature>,
}Expand description
A collection of signatures that can be checked on a networkstatus document
This is derived from the signatures section of a netstatus, https://spec.torproject.org/dir-spec/consensus-formats.html#section:signature, but it is not isomorphic to it, and is not directly parseable.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.hashes: DirectorySignaturesHashesAccuThe document hashes of the signed part of the document
The pre-parse2 parser always sets hashes.sha1 and hashes.sha1_unnamed
to the same value, which is wrong. which is
bug #2530
signatures: Vec<Signature>The signatures listed on the document.