pub struct SupersededAuthorityKey { /* private fields */ }Expand description
A dir-source line that is a “superseded authority key entry”
Construct using from_dir_source.
https://spec.torproject.org/dir-spec/consensus-formats.html#item:dir-source
Implementations
Sourceimpl SupersededAuthorityKey
impl SupersededAuthorityKey
Sourcepub fn real_nickname(&self) -> &Nickname
pub fn real_nickname(&self) -> &Nickname
Method borrowing SupersededAuthorityKey::real_nickname field.
Real nickname for this authority, not including the -legacy
Sourcepub fn identity(&self) -> &Fingerprint
pub fn identity(&self) -> &Fingerprint
Method borrowing SupersededAuthorityKey::identity field.
Fingerprint for the authority identity key of this
Sourcepub fn hostname(&self) -> &InternetHost
pub fn hostname(&self) -> &InternetHost
Method borrowing SupersededAuthorityKey::hostname field.
IP address for the authority
Sourcepub fn ip(&self) -> &IpAddr
pub fn ip(&self) -> &IpAddr
Method borrowing SupersededAuthorityKey::ip field.
IP address for the authority
Sourcepub fn dir_port(&self) -> &u16
pub fn dir_port(&self) -> &u16
Method borrowing SupersededAuthorityKey::dir_port field.
HTTP directory port for this authority
Sourcepub fn or_port(&self) -> &u16
pub fn or_port(&self) -> &u16
Method borrowing SupersededAuthorityKey::or_port field.
OR port for this authority.
Sourceimpl SupersededAuthorityKey
impl SupersededAuthorityKey
Sourcepub fn raw_nickname_string(&self) -> &str
pub fn raw_nickname_string(&self) -> &str
The raw nickname, including “-legacy”
Sourcepub fn from_dir_source(ds: DirSource) -> Self
pub fn from_dir_source(ds: DirSource) -> Self
Make a superseded authority key entry from the data in a DirSource
ds.nickname is the real nickname (without -legacy).
ds.fingerprint is the superseded key.