RouterDesc

Struct RouterDesc 

#[non_exhaustive]
pub struct RouterDesc {
Show 25 fields pub router: RouterDescIntroItem, pub identity_ed25519: EmbeddedCert<Ed25519IdentityCert, KeyUnknownCert>, pub master_key_ed25519: Ed25519Public, pub bandwidth: Bandwidth, pub platform: Option<RelayPlatform>, pub published: Iso8601TimeSp, pub fingerprint: Option<SpFingerprint>, pub hibernating: NumericBoolean, pub uptime: Option<u64>, pub onion_key: Option<PublicKey>, pub ntor_onion_key: Curve25519Public, pub ntor_onion_key_crosscert: NtorOnionKeyCrossCert, pub signing_key: PublicKey, pub ipv4_policy: AddrPolicy, pub ipv6_policy: Intern<PortPolicy>, pub overload_general: Option<OverloadGeneral>, pub contact: Option<ContactInfo>, pub family: Intern<RelayFamily>, pub family_cert: RetainedOrderVec<EmbeddedCert<Ed25519FamilyCert, KeyUnknownCert>>, pub caches_extra_info: Option<ItemPresent<CachesExtraInfoToken>>, pub extra_info_digest: Option<ExtraInfoDigests>, pub hidden_service_dir: Option<ItemPresent<HiddenServiceDirToken>>, pub or_address: Vec<SocketAddr>, pub tunnelled_dir_server: Option<ItemPresent<TunnelledDirServerToken>>, pub proto: Protocols,
}
Information about a relay, parsed from a router descriptor.

This type does not hold all the information in the router descriptor

Limitations

See module documentation.

Additionally, some fields that from router descriptors are not yet parsed: see the comments in ROUTER_BODY_RULES for information about those.

Before using this type to connect to a relay, you MUST check that it is valid, using is_expired_at().

Specification

https://spec.torproject.org/dir-spec/server-descriptor-format.html

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
router: RouterDescIntroItem

router — Introduce a router descriptor.

  • router <nickname> <address> <orport> <socksport> <dirport>
  • At start, exactly once.
identity_ed25519: EmbeddedCert<Ed25519IdentityCert, KeyUnknownCert>

identity-ed25519 — Specify the router’s ed25519 identity.

https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:identity-ed25519

master_key_ed25519: Ed25519Public

master-key-ed25519 — Redundantly specify the router’s ed25519 identity.

  • master-key-ed25519 <master key>
  • Exactly once.
bandwidth: Bandwidth

bandwidth — Report router’s network bandwidth.

  • bandwidth <average> <burst> <observed>
  • Exactly once.
platform: Option<RelayPlatform>

platform — Describe the platform on which this relay is running.

  • platform <rest of line>
  • At most once.
published: Iso8601TimeSp

published — Time this descriptor (and extra-info) was generated.

  • published <date> <time>
  • Exactly once.
fingerprint: Option<SpFingerprint>

fingerprint — Redundant hash of ASN-1 encoding of router identity key.

  • fingerprint <spaced fingerprint>
  • At most once.
hibernating: NumericBooleanuptime: Option<u64>

uptime — How long this relay has been continously running

  • uptime <number>
  • At most once.
onion_key: Option<PublicKey>

onion-key — Relay’s obsolete RSA tap key.

  • onion-key\n<rsa public key>
  • At most once.
  • No extra arguments.
ntor_onion_key: Curve25519Public

ntor-onion-key — The circuit extension key.

  • ntor-onion-key <base64 padded key>
  • Exactly once.
ntor_onion_key_crosscert: NtorOnionKeyCrossCert

ntor-onion-key-crosscert — Reverse cert by K_ntor on KP_relayid_ed

https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:ntor-onion-key-crosscert

signing_key: PublicKey

signing-key — Obsolete RSA identity key.

  • signing-key\n<rsa public key>
ipv4_policy: AddrPolicy

accept, reject — Exit policy.

  • accept exitpattern
  • reject exitpattern
  • Any number of times.
ipv6_policy: Intern<PortPolicy>

ipv6-policy — Exit plicy summary for IPv6

  • ipv6-policy <accept/reject> PortList
  • At most once.
overload_general: Option<OverloadGeneral>

overload-general — Relay is overloaded.

  • overload-general 1 <time>
  • At most once.
contact: Option<ContactInfo>

contact — Server administrator contact information.

https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:contact

family: Intern<RelayFamily>

family — Group relays for the purpose of path selection.

  • family <LongIdent> ...
  • One or more LongIdent arguments.
  • At most once.
family_cert: RetainedOrderVec<EmbeddedCert<Ed25519FamilyCert, KeyUnknownCert>>

family-cert — Prove membership in a relay family.

  • family-cert\n<object>
  • Any number of times.
caches_extra_info: Option<ItemPresent<CachesExtraInfoToken>>

caches-extra-info — Router provides extra-info as a dirmirror.

  • caches-extra-info
  • At most once.
  • No extra arguments.
extra_info_digest: Option<ExtraInfoDigests>hidden_service_dir: Option<ItemPresent<HiddenServiceDirToken>>

hidden-service-dir — Declares this router to be a hidden service directory

https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:hidden-service-dir

or_address: Vec<SocketAddr>tunnelled_dir_server: Option<ItemPresent<TunnelledDirServerToken>>

tunnelled-dir-server — Accepts a BEGIN_DIR relay message.

  • tunnelled-dir-server
  • At most once.
  • No extra arguments.
proto: Protocols

proto — Subprotocol capabilities supported.

  • proto <entries>
  • Exactly once.

Implementations

Source

impl RouterDesc

pub fn rsa_identity(&self) -> RsaIdentity

Return a reference to this relay’s RSA identity.

pub fn ed_identity(&self) -> &Ed25519Identity

Return a reference to this relay’s Ed25519 identity.

pub fn protocols(&self) -> &Protocols

Return a reference to the list of subprotocol versions supported by this relay.

pub fn ntor_onion_key(&self) -> &PublicKey

Return a reference to this relay’s Ntor onion key.

pub fn published(&self) -> SystemTime

Return the publication

pub fn or_ports(&self) -> impl Iterator<Item = SocketAddr> + '_

Return an iterator of every SocketAddr at which this descriptor says its relay can be reached.

pub fn family(&self) -> Intern<RelayFamily>

Return the declared family of this descriptor.

pub fn family_ids(&self) -> RelayFamilyIds

Return the authenticated family IDs of this descriptor.

pub fn parse(s: &str) -> Result<UncheckedRouterDesc>

Try to parse s as a router descriptor.

Does not actually check liveness or signatures; you need to do that yourself before you can do the output.

The following fields are not parsed with the legacy parser and their default value is used instead.