pub struct MultiplicitySelector<Field>(PhantomData<fn(Field)>);Expand description
Helper type that allows us to select an impl of MultiplicityMethods
For use by macros.
This is distinct from parse2::MultiplicitySelector,
principally because it has the opposite variance.
Tuple Fields
0: PhantomData<fn(Field)>Implementations
Sourceimpl<T> MultiplicitySelector<Vec<T>>
impl<T> MultiplicitySelector<Vec<T>>
Sourcepub fn selector(self) -> DeterminedMultiplicitySelector<Vec<T>>
pub fn selector(self) -> DeterminedMultiplicitySelector<Vec<T>>
Return the appropriate implementor of MultiplicityMethods
This is an inherent method so that it doesn’t need the EncodeOrd bounds:
that way if EncodeOrd is not implemented, we get a message about that,
rather than a complaint that ItemValueEncodable isn’t impl for Vec<T>.