pub struct NetdocEncoder {
built: Result<String, Bug>,
}Expand description
Encoder, representing a partially-built document.
For example usage, see the tests in this module, or a descriptor building
function in tor-netdoc (such as hsdesc::build::inner::HsDescInner::build_sign).
Fields
built: Result<String, Bug>The being-built document, with everything accumulated so far
If an ItemEncoder exists, it will add a newline when it’s dropped.
Err means bad values passed to some builder function.
Such errors are accumulated here for the benefit of handwritten document encoders.
Implementations
Sourceimpl NetdocEncoder
impl NetdocEncoder
Sourcepub fn item(&mut self, keyword: impl KeywordEncodable) -> ItemEncoder<'_>
pub fn item(&mut self, keyword: impl KeywordEncodable) -> ItemEncoder<'_>
Adds an item to the being-built document
The item can be further extended with arguments or an object,
using the returned ItemEncoder.
Sourcefn write_with(&mut self, f: impl FnOnce(&mut String) -> Result<(), Bug>)
fn write_with(&mut self, f: impl FnOnce(&mut String) -> Result<(), Bug>)
Extend the being-built document with a fallible function f
Doesn’t call f if the building has already failed,
and handles the error if f fails.
Sourcepub fn push_raw_string(&mut self, s: &dyn Display)
pub fn push_raw_string(&mut self, s: &dyn Display)
Adds raw text to the being-built document
s is added as raw text, after the newline ending the previous item.
If item is subsequently called, the start of that item
will immediately follow s.
It is the responsibility of the caller to obey the metadocument syntax.
In particular, s should end with a newline.
No checks are performed.
Incorrect use might lead to malformed documents, or later errors.
Sourcepub fn slice(&self, begin: Cursor, end: Cursor) -> Result<&str, Bug>
pub fn slice(&self, begin: Cursor, end: Cursor) -> Result<&str, Bug>
Obtain the text of a section of the document
Useful for making a signature.
Sourcepub fn text_sofar(&self) -> Result<&str, Bug>
pub fn text_sofar(&self) -> Result<&str, Bug>
Obtain the document so far in textual form