macro_rules! stop_at {
{} => { ... };
}Expand description
“Type alias” for StopAt<impl Fn(KeywordRef<'_>) -> Option<Stop>>
This has to be a macro because the impl is a different type at each call site;
even TAIT wouldn’t help with thaat.
macro_rules! stop_at {
{} => { ... };
}“Type alias” for StopAt<impl Fn(KeywordRef<'_>) -> Option<Stop>>
This has to be a macro because the impl is a different type at each call site;
even TAIT wouldn’t help with thaat.