pub(crate) struct SectionRulesBuilder<T: Keyword> {
strict: bool,
rules: SectionRules<T>,
}Expand description
A builder for a set of section rules.
Fields
strict: boolHave we been told, explicitly, to reject unrecognized tokens?
rules: SectionRules<T>The rules we’re building.
Implementations
Sourceimpl<T: Keyword> SectionRulesBuilder<T>
impl<T: Keyword> SectionRulesBuilder<T>
Sourcepub(crate) fn add(&mut self, t: TokenFmtBuilder<T>)
pub(crate) fn add(&mut self, t: TokenFmtBuilder<T>)
Add a rule to this SectionRulesBuilder, based on a TokenFmtBuilder.
Requires that no rule yet exists for the provided keyword.
Sourcepub(crate) fn reject_unrecognized(&mut self)
pub(crate) fn reject_unrecognized(&mut self)
Explicitly reject any unrecognized tokens.
To avoid errors, you must either explicitly reject unrecognized tokens, or you must define how they are handled.
Sourcepub(crate) fn build(self) -> SectionRules<T>
pub(crate) fn build(self) -> SectionRules<T>
Construct the SectionRules from this builder.
Panics
Panics if you did not specify the behavior for unrecognized tokens,
using either reject_unrecognized or add(UNRECOGNIZED.rule()...)