pub(crate) struct MaybeItem<'a, 'b, K: Keyword>(Option<&'a Item<'b, K>>);Expand description
Represents an Item that might not be present, whose arguments we want to inspect. If the Item is there, this acts like a proxy to the item; otherwise, it treats the item as having no arguments.
Tuple Fields
0: Option<&'a Item<'b, K>>Implementations
Sourceimpl<'a, 'b, K: Keyword> MaybeItem<'a, 'b, K>
impl<'a, 'b, K: Keyword> MaybeItem<'a, 'b, K>
Sourcepub(crate) fn from_option(opt: Option<&'a Item<'b, K>>) -> Self
pub(crate) fn from_option(opt: Option<&'a Item<'b, K>>) -> Self
Construct a MaybeItem from an Option reference to an item.
Sourcepub(crate) fn parse_arg<V: FromStr>(&self, idx: usize) -> Result<Option<V>>
pub(crate) fn parse_arg<V: FromStr>(&self, idx: usize) -> Result<Option<V>>
If this item is present, parse its argument at position idx.
Treat the absence or malformedness of the argument as an error,
but treat the absence of this item as acceptable.
Sourcepub(crate) fn args_as_str(&self) -> Option<&str>
pub(crate) fn args_as_str(&self) -> Option<&str>
If this item is present, return its arguments as a single string.