derive_deftly_module_NetdocSomeItemsParseableCommon

Macro derive_deftly_module_NetdocSomeItemsParseableCommon 

macro_rules! derive_deftly_module_NetdocSomeItemsParseableCommon {
    (
        via_modules[{ $($our_opts:tt)* } $next_macro:path { $($next_opts:tt)*
        } $($rest:tt)*] { $($predefs:tt)* } { $($main:tt)* } ($($extra:tt)*)
        $($ignored:tt)*
    ) => { ... };
    ($($wrong:tt)*) => { ... };
}
Common definitions for NetdocParseable, NetdocParseableFields, and NetdocParseableSignatures

The including macro is expected to define:

  • THIS_ITEM: consumes the next item and evaluates to it as an UnparsedItem. See the definition in NetdocParseable.

  • F_ACCUMULATE_VAR the variable or field into which to accumulate normal items for this field. Must be of type &mut $F_ACCUMULATE_TYPE.

Importer must also import NetdocSomeItemsDeriveCommon and NetdocDeriveAnyCommon.

This is a derive_deftly reuseable template code module. Do not invoke it directly.