parse_netdoc_multiple_sophisticated

Function parse_netdoc_multiple_sophisticated 

pub fn parse_netdoc_multiple_sophisticated<D: NetdocParseable>(
    input: &ParseInput<'_>,
) -> Result<Vec<(Result<D, ParseError>, usize, usize)>, Bug>
Parse multiple network documents, with error recovery - toplevel entrypoint

Parses multiple documents. If an error is encountered, it is returned, and parsing continues with the next document (if possible).

Each document or error is accompanied by the applicable byte offsets in the input document, as with parse_netdoc_multiple_with_offsets.