NetworkStatusUnverifiedParsedBody

Struct NetworkStatusUnverifiedParsedBody 

pub struct NetworkStatusUnverifiedParsedBody {
    unverified: NetworkStatus,
}
The parsed but unverified body part of a signed network document (working type)

Contains a NetworkStatus which has been parsed as part of a signed document, but the signatures aren’t embodied here, and have not been verified.

Not very useful to callers, who should use the BodyUnverified type instead, and its implementation of NetdocParseable.

Fields

unverified: NetworkStatus

The unverified body