#[non_exhaustive]pub struct DirectorySignaturesHashesAccu {
sha1: Option<[u8; 20]>,
sha256: Option<[u8; 32]>,
}Expand description
directory-signaturea hash algorithm argument
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sha1: Option<[u8; 20]>SHA-1
sha256: Option<[u8; 32]>SHA-256
Implementations
Sourceimpl DirectorySignaturesHashesAccu
impl DirectorySignaturesHashesAccu
Sourcefn parse_keyword_and_hash(
&mut self,
algorithm: &str,
body: &SignatureHashInputs<'_>,
) -> Option<DirectorySignatureHashAlgo>
fn parse_keyword_and_hash( &mut self, algorithm: &str, body: &SignatureHashInputs<'_>, ) -> Option<DirectorySignatureHashAlgo>
If algorithm is an algorithm name, calculate the hash
Otherwise, return None.
Sourcefn hash_slice_for_verification(
&self,
algo: DirectorySignatureHashAlgo,
) -> Option<&[u8]>
fn hash_slice_for_verification( &self, algo: DirectorySignatureHashAlgo, ) -> Option<&[u8]>
Return the hash value for this algorithm, as a slice
None if the value wasn’t computed.
That shouldn’t happen.