RouterVote

Type Alias RouterVote 

pub type RouterVote = VoteRouterStatus;
The real router status entry type.

Aliased Type

pub struct RouterVote {
    pub r: RouterStatusIntroItem,
    pub m: Vec<RouterStatusMdDigestsVote>,
    pub a: Vec<SocketAddr>,
    pub flags: DocRelayFlags,
    pub version: Option<SoftwareVersion>,
    pub protos: Protocols,
    pub weight: RelayWeightsItem,
    pub port_policy: Option<Arc<PortPolicy>>,
    pub ed25519_id: Ed25519IdentityLine,
    pub stats: NetParams<F64Finite>,
}

Fields

r: RouterStatusIntroItem

r — Introduce a routerstatus entry

https://spec.torproject.org/dir-spec/consensus-formats.html#item:r (and, the md version, which is different).

m: Vec<RouterStatusMdDigestsVote>

m — Microdescriptor or document digest

In an md consensus, the hash of the document for this relay. In a vote, microdescriptor hashes for the various consensus methods.

https://spec.torproject.org/dir-spec/computing-consensus.html#flavor:microdesc r item.

a: Vec<SocketAddr>

a — Further router address(es) (IPv6)

https://spec.torproject.org/dir-spec/consensus-formats.html#item:a (and, the md version, which is different).

flags: DocRelayFlagsversion: Option<SoftwareVersion>protos: Protocolsweight: RelayWeightsItemport_policy: Option<Arc<PortPolicy>>

p — Exit ports summary

https://spec.torproject.org/dir-spec/consensus-formats.html#item:p

This field is not properly parsed in plain consensuses by the old parser.

ed25519_id: Ed25519IdentityLinestats: NetParams<F64Finite>