SignedDocumentBody

Struct SignedDocumentBody 

pub struct SignedDocumentBody<'s> {
    pub(crate) body: &'s str,
}
The part of a network document before the first signature item

This is used for both Orderly signatures where the hash does not contain any part of the signature Item nor of any further signatures. and Disorderly signatures where the hash contains part of the signature Item. (The Tor protocols currently only have Disorderly signatures.)

See “Signature item ordering, and signatures covering signatures” in the NetdocParseableSignatures derive and https://gitlab.torproject.org/tpo/core/torspec/-/issues/322.

Fields

body: &'s str

The actual body as a string

Implementations

Source

impl<'s> SignedDocumentBody<'s>

pub fn body(&self) -> &'s str

Method returning copy of SignedDocumentBody::body field. The actual body as a string