pub struct NoFurtherArguments;Expand description
Indicates that no further arguments are allowed in a network document Item line
Unlike NotPresent, this fails during parsing if there are any more arguments.
Should appear only at the end of the argument list.