#[non_exhaustive]pub struct SignaturesData<U: NetdocUnverified> {
pub sigs: U::Signatures,
pub unsigned_body_len: usize,
pub hashes: <U::Signatures as NetdocParseableSignatures>::HashesAccu,
}Expand description
The signatures information extracted from a signed network document
Each SomeDocumentUnverified contains:
- private
SomeDocument, - public
SignatureData<SomeDocumentSignatures>
See NetdocUnverified
and the NetdocParseable derive.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sigs: U::SignaturesThe signatures themselves, each including the corresponding hash
unsigned_body_len: usizeThe length in bytes of the body, up to the start of the first signature item.
hashes: <U::Signatures as NetdocParseableSignatures>::HashesAccuThe hashes which were computed as part of parsing.
This will include every hash computed by any signature item’s
SignatureItemParseable implementation.