#[non_exhaustive]pub struct Error {
pub(crate) kind: NetdocErrorKind,
msg: Option<Cow<'static, str>>,
pos: Pos,
source: Option<NetdocErrorSource>,
}Expand description
An error that occurred while parsing a directory object of some kind.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: NetdocErrorKindWhat kind of error occurred?
msg: Option<Cow<'static, str>>Do we have more information about the error?>
pos: PosWhere did the error occur?
source: Option<NetdocErrorSource>Was this caused by another error?
Implementations
Sourceimpl Error
impl Error
Sourcepub fn within(self, s: &str) -> Error
pub fn within(self, s: &str) -> Error
Return a new error based on this one, with any byte-based position mapped to some line within a string.
Sourcepub fn at_pos(self, p: Pos) -> Error
pub fn at_pos(self, p: Pos) -> Error
Return a new error based on this one, with the position (if any) replaced by ‘p’.
Sourcepub fn or_at_pos(self, p: Pos) -> Error
pub fn or_at_pos(self, p: Pos) -> Error
Return a new error based on this one, with the position (if replaced by ‘p’ if it had no position before.
Sourcepub(crate) fn with_msg<T>(self, message: T) -> Error
pub(crate) fn with_msg<T>(self, message: T) -> Error
Return a new error based on this one, with the message value set to a provided static string.
Sourcepub(crate) fn with_source<T>(self, source: T) -> Errorwhere
T: Into<NetdocErrorSource>,
pub(crate) fn with_source<T>(self, source: T) -> Errorwhere
T: Into<NetdocErrorSource>,
Return a new error based on this one, with the source-error value set to the provided error.
Sourcepub fn netdoc_error_kind(&self) -> NetdocErrorKind
pub fn netdoc_error_kind(&self) -> NetdocErrorKind
Return the NetdocErrorKind of this error.