KeywordOrString

Enum KeywordOrString 

pub enum KeywordOrString<T: Copy> {
    Known(T),
    Unknown(String),
}
Known keyword (enum) value, or arbitrary string

T should be a Copy enum with unit variants. It should have appropriate FromStr and Display, as well as NormalItemArgument, impls.

Then KeywordOrString will implement the same traits.

Unlike Unknown, unknown values are always retained as strings.

Variants



Known(T)

Known and recognised T



Unknown(String)

Unknown value in arbitrary syntax