#[non_exhaustive]pub enum RelayFamilyId {
Ed25519(Ed25519Identity),
Unrecognized(String),
}Expand description
An identifier representing a relay family.
In the “happy families” scheme, microdescriptors will no longer have to contain a list of relay members, but will instead contain these identifiers.
If two relays have a RelayFamilyId in common, they belong to the same family.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ed25519(Ed25519Identity)
An identifier derived from an Ed25519 relay family key. (KP_familyid_ed)
Unrecognized(String)
An unrecognized string.