LongIdent

Struct LongIdent 

pub(crate) struct LongIdent(pub RsaIdentity);
A “long identity” in the format used for Family members.

Netdoc parsing adapter for RsaIdentity

Tuple Fields

0: RsaIdentity

Methods from Deref<Target = RsaIdentity>

pub fn as_bytes(&self) -> &[u8]

Expose an RsaIdentity as a slice of bytes.

pub fn to_bytes(&self) -> [u8; 20]

Expose an RsaIdentity as a byte array.

pub fn as_hex_upper(&self) -> String

Expose an RsaIdentity as an uppercase hexadecimal string.

pub fn is_zero(&self) -> bool

Return true if this RsaIdentity is composed entirely of zero-valued bytes.

Such all-zero values should not be used internally, since they are not the ID of any valid key. Instead, they are used in some places in the Tor protocols.