Nickname

Struct Nickname 

pub struct Nickname(TinyAsciiStr<MAX_NICKNAME_LEN>);
The nickname for a Tor relay.

These nicknames are legacy mechanism that’s occasionally useful in debugging. They should never be used to uniquely identify relays; nothing prevents two relays from having the same nickname.

Nicknames are required to be ASCII, alphanumeric, and between 1 and 19 characters inclusive.

Tuple Fields

0: TinyAsciiStr<MAX_NICKNAME_LEN>

Implementations

Source

impl Nickname

pub(crate) fn as_str(&self) -> &str

Return a view of this nickname as a string slice.