pub struct RouterSignature(pub Vec<u8>);Expand description
SHA-1 router descriptor signature over router-sig-ed25519.
Tuple Fields
0: Vec<u8>Trait Implementations
Sourceimpl Clone for RouterSignature
impl Clone for RouterSignature
Sourcefn clone(&self) -> RouterSignature
fn clone(&self) -> RouterSignature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RouterSignature
impl Debug for RouterSignature
Sourceimpl PartialEq for RouterSignature
impl PartialEq for RouterSignature
Sourcefn eq(&self, other: &RouterSignature) -> bool
fn eq(&self, other: &RouterSignature) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SignatureItemParseable for RouterSignature
impl SignatureItemParseable for RouterSignature
Sourcetype HashAccu = RouterHashAccu
type HashAccu = RouterHashAccu
The Rust type of the hash value accumulator for this item. Read more
Sourcefn from_unparsed_and_body(
item: UnparsedItem<'_>,
hash_inputs: &SignatureHashInputs<'_>,
hash: &mut Self::HashAccu,
) -> Result<Self, EP>
fn from_unparsed_and_body( item: UnparsedItem<'_>, hash_inputs: &SignatureHashInputs<'_>, hash: &mut Self::HashAccu, ) -> Result<Self, EP>
Parse the item’s value, and also calculate the relevant document hash Read more
impl Eq for RouterSignature
impl StructuralPartialEq for RouterSignature