pub(crate) struct RsaPublicParse1Helper(PublicKey, Pos);Expand description
RSA public key, partially processed by crate::paarse.
As parsed from a base64-encoded object. They key’s properties (exponent and size) haven’t been checked.
Tuple Fields
0: PublicKey1: PosImplementations
Sourceimpl RsaPublicParse1Helper
impl RsaPublicParse1Helper
Sourcepub(crate) fn check_exponent(self, e: u32) -> Result<Self>
pub(crate) fn check_exponent(self, e: u32) -> Result<Self>
Give an error if the exponent of this key is not ‘e’
Sourcepub(crate) fn check_len<B: RangeBounds<usize>>(self, bounds: B) -> Result<Self>
pub(crate) fn check_len<B: RangeBounds<usize>>(self, bounds: B) -> Result<Self>
Give an error if the length of this key’s modulus, in bits, is not contained in ‘bounds’
Sourcepub(crate) fn check_len_eq(self, n: usize) -> Result<Self>
pub(crate) fn check_len_eq(self, n: usize) -> Result<Self>
Give an error if the length of this key’s modulus, in
bits, is not exactly n.