IpPattern

Enum IpPattern 

enum IpPattern {
    Star,
    V4Star,
    V6Star,
    V4(Ipv4Addr, u8),
    V6(Ipv6Addr, u8),
}
A pattern that matches one or more IP addresses.

Variants



Star

Match all addresses.



V4Star

Match all IPv4 addresses.



V6Star

Match all IPv6 addresses.



V4(Ipv4Addr, u8)

Match all IPv4 addresses beginning with a given prefix.



V6(Ipv6Addr, u8)

Match all IPv6 addresses beginning with a given prefix.

Implementations

Source

impl IpPattern

fn from_addr_and_mask(addr: IpAddr, mask: u8) -> Result<Self, PolicyError>

Construct an IpPattern that matches the first mask bits of addr.

fn matches(&self, addr: &IpAddr) -> bool

Return true iff addr is matched by this pattern.