struct AddrPolicyRule {
kind: RuleKind,
pattern: AddrPortPattern,
}Expand description
A single rule in an address policy.
Contains a pattern and what to do with things that match it.
Fields
kind: RuleKindWhat do we do with items that match the pattern?
pattern: AddrPortPatternWhat pattern are we trying to match?