#[non_exhaustive]pub enum PolicyError {
InvalidPort,
InvalidRange,
InvalidAddress,
MaskWithStar,
InvalidMask,
InvalidPolicy,
}Expand description
Error from an unparsable or invalid policy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidPort
A port was not a number in the range 1..65535
InvalidRange
A port range had its starting-point higher than its ending point.
InvalidAddress
An address could not be interpreted.
MaskWithStar
Tried to use a bitmask with the address “*”.
InvalidMask
A bit mask was out of range.
InvalidPolicy
A policy could not be parsed for some other reason.