pub struct AddrPortPattern {
pattern: IpPattern,
ports: PortRange,
}Expand description
A pattern that may or may not match an address and port.
Each AddrPortPattern has an IP pattern, which matches a set of addresses by prefix, and a port pattern, which matches a range of ports.
Example
use tor_netdoc::types::policy::AddrPortPattern;
use std::net::{IpAddr,Ipv4Addr};
let localhost = IpAddr::V4(Ipv4Addr::new(127,3,4,5));
let not_localhost = IpAddr::V4(Ipv4Addr::new(192,0,2,16));
let pat: AddrPortPattern = "127.0.0.0/8:*".parse().unwrap();
assert!(pat.matches(&localhost, 22));
assert!(! pat.matches(¬_localhost, 22));Fields
pattern: IpPatternA pattern to match somewhere between zero and all IP addresses.
ports: PortRangeA pattern to match a range of ports.
Implementations
Sourceimpl AddrPortPattern
impl AddrPortPattern
Sourcepub fn matches(&self, addr: &IpAddr, port: u16) -> bool
pub fn matches(&self, addr: &IpAddr, port: u16) -> bool
Return true iff this pattern matches a given address and port.
Sourcepub fn matches_sockaddr(&self, addr: &SocketAddr) -> bool
pub fn matches_sockaddr(&self, addr: &SocketAddr) -> bool
As matches, but accept a SocketAddr.