pub struct PortPolicies {
pub v4: PortPolicy,
pub v6: PortPolicy,
}Expand description
A pair of port policy summaries, one for IPv4 and one for IPv6
Returned by AddrPolicy::summarise_precise.
Fields
v4: PortPolicyIPv4
v6: PortPolicyIPv6
Implementations
Sourceimpl PortPolicies
impl PortPolicies
Sourcefn from_summariser(
summariser: Summariser,
thresh: &PortSummaryThresholds,
) -> PortPolicies
fn from_summariser( summariser: Summariser, thresh: &PortSummaryThresholds, ) -> PortPolicies
Actually calculate the port policy summaries for both IP versions