pub struct PortSummaryThresholds {
pub v4: u128,
pub v6: u128,
}Expand description
Thresholds for deciding whether a port counts as open, for a summary
Each value is the maximum number of individual addresses that may be blocked before the port is considered closed.
The Default implementation, and PortSummaryThresholds::DEFAULT,
provide the thresholds currently specified in torspec.
We provide this as a controllable parameter so that the summariser is a pure function that doesn’t embed these tuneables. Then if the spec changes, the directory authority consensus calculator can provide the appropriate thresholds depending on the consensus method.
Fields
v4: u128IPv4
Currently, the spec says
no more than 2^25 IPv4 addresses (two /8’s worth, or one /7’s worth)
v6: u128IPv6
Currently, the spec says
no more than 2^112 IPv6 addresses (one /16’s worth)
Implementations
Sourceimpl PortSummaryThresholds
impl PortSummaryThresholds
Sourcepub const DEFAULT: PortSummaryThresholds
pub const DEFAULT: PortSummaryThresholds
Default value, from the Tor Specifications
Sourcepub const fn from_prefix_lengths(
v4_prefix_len: u8,
v6_prefix_len: u8,
) -> PortSummaryThresholds
pub const fn from_prefix_lengths( v4_prefix_len: u8, v6_prefix_len: u8, ) -> PortSummaryThresholds
PortSummaryThresholds from prefix lengths
Returns a PortSummaryThresholds whose thresholds are
“one /v4’s worth” for IPv4
and
“one /v6’s worth” for IPv6.