struct Summariser {
reject: RangeInclusiveMap<u16, Rejects>,
}Expand description
State for summarisation algorithm
We walk the rules in reverse order. The rules are semantically first-match, but we want to walk all the rules, doing all the port updates in parallel, and updating the accept/reject state as we go - i.e. last match wins.
Fields
reject: RangeInclusiveMap<u16, Rejects>Set of IP addresses we are rejecting for each port
Invariants: port 0 is not in the map. Every other port has an entry in the map, even if it’s just two empty IpRanges.
Implementations
Sourceimpl Summariser
impl Summariser
Sourcefn apply_rule(&mut self, rule_kind: RuleKind, pat: &AddrPortPattern)
fn apply_rule(&mut self, rule_kind: RuleKind, pat: &AddrPortPattern)
Apply rule_kind for pat (for all IP versions) to self
Overwrites old information - so last update wins.
Calls Reject::apply_rule once for every relevant combination of:
- port range (via
rangemap_mutate_range) - address family (open-coded, two similar calls)
Sourceimpl Summariser
impl Summariser
Sourcefn policy_for_one_ip_version<N: Net>(
&self,
select_rejects: impl Fn(&Rejects) -> &IpRange<N>,
max_reject_count: u128,
) -> PortPolicy
fn policy_for_one_ip_version<N: Net>( &self, select_rejects: impl Fn(&Rejects) -> &IpRange<N>, max_reject_count: u128, ) -> PortPolicy
Calculate the summary policy for IP version N
select_rejects should pick the corresponding field out of Rejects