RelayFlag

Enum RelayFlag 

#[non_exhaustive]
pub enum RelayFlag {
Show 13 variants Authority, BadExit, Exit, Fast, Guard, HSDir, MiddleOnly, NoEdConsensus, Stable, StaleDesc, Running, Valid, V2Dir,
}
Router status flags - one recognized directory flag on a single relay.

https://spec.torproject.org/dir-spec/consensus-formats.html#item:s

These flags come from a consensus directory document, and are used to describe what the authorities believe about the relay. If the document contained any flags that we didn’t recognize, they are not listed in this type.

TODO SPEC: Make the terminology the same everywhere.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Authority

Is this a directory authority?



BadExit

Is this relay marked as a bad exit?

Bad exits can be used as intermediate relays, but not to deliver traffic.



Exit

Is this relay marked as an exit for weighting purposes?



Fast

Is this relay considered “fast” above a certain threshold?



Guard

Is this relay suitable for use as a guard relay?

Clients choose their their initial relays from among the set of Guard relays.



HSDir

Does this relay participate on the onion service directory ring?



MiddleOnly

Set if this relay is considered “middle only”, not suitable to run as an exit or guard relay.

Note that this flag is only used by authorities as part of the voting process; clients do not and should not act based on whether it is set.



NoEdConsensus

If set, there is no consensus for the ed25519 key for this relay.



Stable

Is this relay considered “stable” enough for long-lived circuits?



StaleDesc

Set if the authorities are requesting a fresh descriptor for this relay.



Running

Set if this relay is currently running.

This flag can appear in votes, but in consensuses, every relay is assumed to be running.



Valid

Set if this relay is considered “valid” – allowed to be on the network.

This flag can appear in votes, but in consensuses, every relay is assumed to be valid.



V2Dir

Set if this relay supports a currently recognized version of the directory protocol.