ReprMode

Trait ReprMode 

pub trait ReprMode: Debug + Copy {
    const PARSE_IMPLICIT: RelayFlags;
    const ENCODE_OMIT: RelayFlags;
}
Additional options for the representation of relay flags in network documents

This is a generic argument to ParserEncoder (and will be used for the encoder too).

Required Associated Constants

const PARSE_IMPLICIT: RelayFlags

Flags that should be treated as being present when parsing

Ie, they should be inferred even if they aren’t actually listed in the document.

But, when encoding, they should still be emitted.

const ENCODE_OMIT: RelayFlags

Flags that should be treated as being present, and won’t even be encoded.

These are inferred when parsing, and omitted when encoding.

(During parsing ENCODE_OMIT and PARSE_IMPLICIT flags are treated the same.)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors