#[non_exhaustive]pub struct Bandwidth {
pub average: u64,
pub burst: u64,
pub observed: u64,
}Expand description
Estimated bandwidth for a router.
https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:bandwidth
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.average: u64The volume that the relay is willing to sustain over long periods.
burst: u64The volume that the relay is willing to sustain in very short intervals.
observed: u64The estimate of the capacity this relay can handle.