pub struct Ed25519FamilyCert {
pub family_ed25519: Ed25519Identity,
}Expand description
An Ed25519 family certificate.
This is a certificate of CertType::FAMILY_V_IDENTITY where the
family key signs the long-term ed25519 identity key of the given relay.
It purposely does not store the long-term ed25519 identity key of the relay because the idea of this type should be equal only to other types with the same family key.
Fields
family_ed25519: Ed25519IdentityThe public key of the family.
Implementations
Sourceimpl Ed25519FamilyCert
impl Ed25519FamilyCert
Sourcepub fn verify(
id_ed25519: Ed25519Identity,
cert: KeyUnknownCert,
) -> StdResult<TimerangeBound<Self>, VerifyFailed>
pub fn verify( id_ed25519: Ed25519Identity, cert: KeyUnknownCert, ) -> StdResult<TimerangeBound<Self>, VerifyFailed>
Verifies the validity of an Ed25519FamilyCert.
For such a certificate to be valid, the caller must provide a known Ed25519 identity key of the relay beforehand.
Requirements
- MUST have the
signed-with-ed25519-keyextension containing the family key. - MUST have a valid signature by the family key.
- MUST be of of
CertType::FAMILY_V_IDENTITY. - Certified key MUST BE of
tor_cert::CertifiedKey::Ed25519. id_ed25519MUST be the certified key.- Both keys MUST be valid mappings to a
ed25519::PublicKey.
Sourcepub fn new_signed(
family_ed25519: &Keypair,
id_ed25519: Ed25519Identity,
expiry: SystemTime,
) -> StdResult<EmbeddedCert<Self, KeyUnknownCert>, Bug>
pub fn new_signed( family_ed25519: &Keypair, id_ed25519: Ed25519Identity, expiry: SystemTime, ) -> StdResult<EmbeddedCert<Self, KeyUnknownCert>, Bug>
Creates a new signed Ed25519FamilyCert.