Ed25519IdentityCert

Struct Ed25519IdentityCert 

pub struct Ed25519IdentityCert {
    pub id_ed25519: Ed25519Identity,
    pub sign_ed25519: Ed25519Identity,
}
An Ed25519 identity certificate.

This is a certificate of CertType::IDENTITY_V_SIGNING where the relay’s long-term ed25519 identity key signs the relay’s medium-term ed25519 signing key, used for signing almost all other certifications associated with a given relay.

Fields

id_ed25519: Ed25519Identity

The long-term ed25519 identity key of the relay

sign_ed25519: Ed25519Identity

The medium-term ed25519 signing key of the relay.

Implementations

Source

impl Ed25519IdentityCert

pub fn verify( cert: KeyUnknownCert, post_tolerance: Duration, now: SystemTime, ) -> StdResult<Self, VerifyFailed>

Verifies the validity of an Ed25519IdentityCert.

Requirements
  1. MUST have the identity key in the signed-with-ed25519-key extension.
  2. MUST have a valid signature by the identity key.
  3. MUST be valid at now.
  4. MUST be of CertType::IDENTITY_V_SIGNING.
  5. Certified key MUST BE of tor_cert::CertifiedKey::Ed25519.
  6. Both keys MUST be different.
  7. Both keys MUST be valid mappings to a ed25519::PublicKey.
pub fn new_signed( id_ed25519: &Keypair, sign_ed25519: Ed25519Identity, expiry: SystemTime, ) -> StdResult<EmbeddedCert<Self, KeyUnknownCert>, Bug>

Creates a new signed Ed25519IdentityCert.