Ed25519NtorCrossCert

Struct Ed25519NtorCrossCert 

#[non_exhaustive]
pub struct Ed25519NtorCrossCert { _promise_we_verified: (), }
Verified reverse cert by K_ntor on KP_relayid_ed

This certificate is signed by KS_ntor (the circuit extension key) and certifies KP_relayid_ed25519 ed25519 identity key of the relay.

The type itself is zero-sized because it provides no new useful information that cannot be found elsewhere within the router descriptor. It is intended for use within EmbeddedCert<Ed25519NtorCrossCert, KeyUnknownCert>

Note on key conversion

Keep in mind however that the ntor onion key is only provided as an X25519 key and not an Ed25519 key, meaning that interfacing applications have to convert it using a function such as tor_llcrypto::pk::keymanip::convert_curve25519_to_ed25519_public(). This also requires obtaining the sign bit which is usually given as an argument in the ntor-onion-key-crosscert item. However, this is outside of the scope of this struct and the code will assume that callers have already converted the X25519 public key to an Ed25519 public key as outlined in the specifications.

See Also

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
_promise_we_verified: ()

Explicit field, to avoid constructing this accidentally without doing all the verification.

Implementations

Source

impl Ed25519NtorCrossCert

pub fn verify( ntor_ed25519: Ed25519Identity, id_ed25519: Ed25519Identity, cert: KeyUnknownCert, ) -> StdResult<TimerangeBound<Self>, VerifyFailed>

Verifies the validity of an Ed25519NtorCrossCert.

For such a certificate to be valid, the caller must provide a known Ed25519 identity key and Ed25519 ntor onion key of the relay beforehand.

Requirements
  1. MUST be of CertType::NTOR_CC_IDENTITY.
  2. Certified key MUST be of CertifiedKey::Ed25519.
  3. Certified key MUST be equal to id_ed25519.
  4. MUST have a valid signature.
pub fn new_signed( ntor_ed25519: &ExpandedKeypair, id_ed25519: Ed25519Identity, expiry: SystemTime, ) -> StdResult<EmbeddedCert<Self, KeyUnknownCert>, Bug>

Creates a new signed Ed25519NtorCrossCert.

pub(crate) fn verify_inner( ntor_ed25519: Ed25519Identity, id_ed25519: Ed25519Identity, cert: KeyUnknownCert, ) -> StdResult<(SignatureGated<TimerangeBound<Self>>, ValidatableEd25519Signature, SystemTime), VerifyFailed>

Verifies the validity of a KeyUnknownCert believed to be a CertType::NTOR_CC_IDENTITY.

This function serves as glue between the legacy parser and Self::verify().

Requirements
  1. MUST be of CertType::NTOR_CC_IDENTITY.
  2. Certified key MUST be of CertifiedKey::Ed25519.
  3. Certified key MUST be equal to id_ed25519.
Return Type

Actual signature and time validation is done by the caller, hence why it returns a gated type as the first element of the tuple. The other elements constitute the inner signature plus the SystemTime denoting the expiry. This is required for integration with legacy parser in order to enable pushing it to the verification batch, as the tor_checkable primitives do not provide access to the inner signatures/expiries and also do not support operations like cloning due to being dyn.

pub(crate) fn dangerous_new_unverified() -> Self

Internal function for creating an unverified instance.

This is only intended for testing and legacy parser compatibility purposes.