Ignored

Struct Ignored 

pub struct Ignored;
Ignored part of a network document.

With parse2, can be used as an item, object, or even flattened-fields.

When deriving parse2 traits, and a field is absent in a particular netstatus variety, use ns_type! with NotPresent, rather than Ignored.

During encoding as an Items or Objects, will be entirely omitted, via the multiplicity arrangements.

Cannot be encoded as an Argument: if this is not the last Argument, we need something to put into the output document to avoid generating a document with the arguments out of step. If it is the last argument, it could simply be omitted, since additional arguments are in any case ignored.