IgnoredItemOrObjectValue

Struct IgnoredItemOrObjectValue 

pub struct IgnoredItemOrObjectValue(Void);
An Item or Object that would be ignored during parsing and is omitted during encoding

This is the “single” item type for encoding multiplicity for Items or Objects, for Ignored.

This type is uninhabited.

Tuple Fields

0: Void