pub struct ItemPresent<T: Default>(pub T);Expand description
An item that only matters in terms of presence of absence.
Useful for items such as tunnelled-dir-server where the mere presence
implies a truthful value.
This wrapper implements ItemValueParseable and ItemValueEncodable
rejecting all arguments and objects and just expecting/emitting the
keyword (or not).
Examples
The following shows an except from a hypothetical netdoc with a
ItemPresent item.
use derive_deftly::Deftly;
use tor_netdoc::types::*;
use tor_netdoc::parse2::*;
use tor_netdoc::*;
#[derive(Debug, Default)]
struct Hello;
#[derive(Deftly, Debug)]
#[derive_deftly(NetdocParseable)]
struct TestDoc {
intro: Ignored,
hello: Option<ItemPresent<Hello>>,
}
// hello is not present.
let doc = parse_netdoc::<TestDoc>(&ParseInput::new("intro\n", "")).unwrap();
assert!(doc.hello.is_none());
// hello is present.
let doc = parse_netdoc::<TestDoc>(&ParseInput::new("intro\nhello\n", "")).unwrap();
assert!(doc.hello.is_some());
// hello has arguments which are ignored.
let doc = parse_netdoc::<TestDoc>(&ParseInput::new("intro\nhello world\n", "")).unwrap();
assert!(doc.hello.is_some());
// hello is present twice which is not allowed.
let doc = parse_netdoc::<TestDoc>(&ParseInput::new("intro\nhello\nhello\n", "")).unwrap_err();Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Default> AsMut<T> for ItemPresent<T>
impl<T: Default> AsMut<T> for ItemPresent<T>
Sourceimpl<T: Default> AsRef<T> for ItemPresent<T>
impl<T: Default> AsRef<T> for ItemPresent<T>
Sourceimpl<T: Clone + Default> Clone for ItemPresent<T>
impl<T: Clone + Default> Clone for ItemPresent<T>
Sourcefn clone(&self) -> ItemPresent<T>
fn clone(&self) -> ItemPresent<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<T: Copy + Default> Copy for ItemPresent<T>
Sourceimpl<T: Default + Default> Default for ItemPresent<T>
impl<T: Default + Default> Default for ItemPresent<T>
Sourcefn default() -> ItemPresent<T>
fn default() -> ItemPresent<T>
Returns the “default value” for a type. Read more
Sourceimpl<T: Default> Deref for ItemPresent<T>
impl<T: Default> Deref for ItemPresent<T>
Sourceimpl<T: Default> DerefMut for ItemPresent<T>
impl<T: Default> DerefMut for ItemPresent<T>
impl<T: Eq + Default> Eq for ItemPresent<T>
Sourceimpl<T: Default> From<T> for ItemPresent<T>
impl<T: Default> From<T> for ItemPresent<T>
Sourceimpl<T: Default> ItemValueEncodable for ItemPresent<T>
impl<T: Default> ItemValueEncodable for ItemPresent<T>
Sourcefn write_item_value_onto(&self, out: ItemEncoder<'_>) -> StdResult<(), Bug>
fn write_item_value_onto(&self, out: ItemEncoder<'_>) -> StdResult<(), Bug>
Write the item’s arguments, and any object, onto
out Read moreSourceimpl<T: Default> ItemValueParseable for ItemPresent<T>
impl<T: Default> ItemValueParseable for ItemPresent<T>
Sourcefn from_unparsed(item: UnparsedItem<'_>) -> StdResult<Self, EP>
fn from_unparsed(item: UnparsedItem<'_>) -> StdResult<Self, EP>
Parse the item’s value
Sourceimpl<T: Ord + Default> Ord for ItemPresent<T>
impl<T: Ord + Default> Ord for ItemPresent<T>
Sourcefn cmp(&self, other: &ItemPresent<T>) -> Ordering
fn cmp(&self, other: &ItemPresent<T>) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T: PartialEq + Default> PartialEq for ItemPresent<T>
impl<T: PartialEq + Default> PartialEq for ItemPresent<T>
Sourcefn eq(&self, other: &ItemPresent<T>) -> bool
fn eq(&self, other: &ItemPresent<T>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<T: PartialOrd + Default> PartialOrd for ItemPresent<T>
impl<T: PartialOrd + Default> PartialOrd for ItemPresent<T>
impl<T: PartialEq + Default> StructuralPartialEq for ItemPresent<T>