#[repr(u8)]enum TorVerStatus {
Other = 0,
Alpha = 1,
Beta = 2,
Rc = 3,
Stable = 4,
}Expand description
Represents the status tag on a Tor version number
Status tags indicate that a release is alpha, beta (seldom used), a release candidate (rc), or stable.
We accept unrecognized tags, and store them as “Other”.
Variants
Other = 0
An unknown release status
Alpha = 1
An alpha release
Beta = 2
A beta release
Rc = 3
A release candidate
Stable = 4
A stable release
Implementations