pub struct TorVersion {
major: u8,
minor: u8,
micro: u8,
patch: u8,
status: TorVerStatus,
dev: bool,
}Expand description
A parsed Tor version number.
Fields
major: u8Major version number. This has been zero since Tor was created.
minor: u8Minor version number.
micro: u8Micro version number. The major, minor, and micro version numbers together constitute a “release series” that starts as an alpha and eventually becomes stable.
patch: u8Patchlevel within a release series
status: TorVerStatusStatus of a given release
dev: boolTrue if this version is given the “-dev” tag to indicate that it isn’t a real Tor release, but rather indicates the state of Tor within some git repository.