pub struct Batches<II, I, F> {
input: Input<II, I, F>,
no_drain: Option<NoDrainToken>,
yield_one: Option<EvenYieldOneBatchStarting>,
}Expand description
An iterator-like object yielding an iterator for each batch.
Each call to .next_batch()
yields an iterator for one subsequent batch,
which in turn will yield the individual items.
Batches is not an Iterator because
its returned item type (the sub-iterator)
borrows it mutably.
II is the iterator item type. I is the input iterator.
F is the predicate for testing if an item is batch-starting.
Fields
input: Input<II, I, F>Input
no_drain: Option<NoDrainToken>Should we avoid draining the end of the previous batch
yield_one: Option<EvenYieldOneBatchStarting>Should we yield even (one) batch-starting item
Implementations
Sourceimpl<II, I: Iterator<Item = II> + PeekableIterator, F: FnMut(&II) -> bool> Batches<II, I, F>
impl<II, I: Iterator<Item = II> + PeekableIterator, F: FnMut(&II) -> bool> Batches<II, I, F>
Sourcepub fn next_batch(&mut self) -> Option<Batch<'_, II, I, F>>
pub fn next_batch(&mut self) -> Option<Batch<'_, II, I, F>>
Proceed to the next batch
If the input is exhausted (ie, there is no next batch), returns None.
Any un-yielded items remaining in the previous batch will be discarded.