define_directory_signature_hash_algo

Macro define_directory_signature_hash_algo 

macro_rules! define_directory_signature_hash_algo {
    { $( $attrs:tt )* } => { ... };
}
Define DirectorySignatureHashAlgo, for directory-signature items

This macro exists to avoid clone-and-hack between poc and prod code.

It is difficult for either of those modules to use the other’s definition, because they have different stability, different cfg gating, and want to derive deftly differently.

tl;dr: defining this type in doc/netstatus.rs would mean the poc derived structs would end up in the prod module; defining it in poc puts it behind the incomplete feature gate.