Sealed

Trait Sealed 

pub trait Sealed { }
A non-exported trait, used to prevent others from implementing a trait.

For more information on this pattern, see the Rust API guidelines.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors