pub(crate) struct Extent {
offset: usize,
length: usize,
sliceptr: *const u8,
slicelen: usize,
}Expand description
An extent within a given string slice.
This whole type is probably naughty and shouldn’t exist. We use it only within this crate, to remember where it was that we found parsed objects within the strings we got them from.
Fields
offset: usizeAt what position within the original string is this extent, in bytes?
length: usizeHow long is this extend, in bytes?
sliceptr: *const u8What was the original string?
If this doesn’t match, there’s been an error.
slicelen: usizeHow long was the original string?
If this doesn’t match, there’s been an error.
Implementations
Sourceimpl Extent
impl Extent
Sourcepub(crate) fn new(haystack: &str, needle: &str) -> Option<Extent>
pub(crate) fn new(haystack: &str, needle: &str) -> Option<Extent>
Construct a new extent to represent the position of needle
within haystack.
Return None if needle is not in fact a slice of haystack.
Sourcepub(crate) fn reconstruct<'a>(&self, haystack: &'a str) -> Option<&'a str>
pub(crate) fn reconstruct<'a>(&self, haystack: &'a str) -> Option<&'a str>
Reconstruct the original needle within haystack.
Return None if we’re sure that the haystack doesn’t match the one we were originally given.
Note that it is possible for this to give a bogus result if provided a new haystack that happens to be at the same position in memory as the original one.