pub struct VarietyKeyword;Expand description
The md keyword in a microdescriptor consensus heading line
This type is one of the fields in NetworkStatusVersionItem.
md consensuses start with network-status-version 3 md ...
In our terminology this is an md consensus, in but the protocol it’s microdesc
So in this variety, the variety it’s the fixed string microdesc.