pub struct PreambleConstructor {
pub consensus_methods: NotPresent,
pub consensus_method: (u32,),
pub published: NotPresent,
pub lifetime: Lifetime,
pub client_versions: Vec<String>,
pub server_versions: Vec<String>,
pub known_flags: DocRelayFlags,
pub proto_statuses: Arc<ProtoStatuses>,
pub params: NetParams<i32>,
}Expand description
Constructor (required fields) for Preamble
See Preamble.
This constructor struct contains precisely the required fields.
You can make a Preamble out of it with .construct(),
or the From impl,
and use the result as a basis for further modifications.
Example
let preamble = Preamble {
voting_delay: /* optional field value */,
shared_rand_previous_value: /* optional field value */,
shared_rand_current_value: /* optional field value */,
__non_exhaustive: /* optional field value */,
..PreambleConstructor {
consensus_methods: /* required field value */,
consensus_method: /* required field value */,
published: /* required field value */,
lifetime: /* required field value */,
client_versions: /* required field value */,
server_versions: /* required field value */,
known_flags: /* required field value */,
proto_statuses: /* required field value */,
params: /* required field value */,
}.construct()
};Fields
consensus_methods: NotPresentConsensus methods supported by this voter.
consensus_method: (u32,)What “method” was used to produce this consensus? (A consensus method is a version number used by authorities to upgrade the consensus algorithm.)
published: NotPresentPublication time (of a vote)
lifetime: LifetimeOver what time is this consensus valid? (For votes, this is the time over which the voted-upon consensus should be valid.)
client_versions: Vec<String>List of recommended Tor client versions.
server_versions: Vec<String>List of recommended Tor relay versions.
known_flags: DocRelayFlagsRouter flags which could be determined
proto_statuses: Arc<ProtoStatuses>Lists of recommended and required subprotocols.
{recommended,required}-{client,relay}-protocols
params: NetParams<i32>Declared parameters for tunable settings about how to the network should operator. Some of these adjust timeouts and whatnot; some features things on and off.
Implementations