#[non_exhaustive]pub struct RouterDesc {Show 25 fields
pub router: RouterDescIntroItem,
pub identity_ed25519: EmbeddedCert<Ed25519IdentityCert, KeyUnknownCert>,
pub master_key_ed25519: Ed25519Public,
pub bandwidth: Bandwidth,
pub platform: Option<RelayPlatform>,
pub published: Iso8601TimeSp,
pub fingerprint: Option<SpFingerprint>,
pub hibernating: NumericBoolean,
pub uptime: Option<u64>,
pub onion_key: Option<PublicKey>,
pub ntor_onion_key: Curve25519Public,
pub ntor_onion_key_crosscert: NtorOnionKeyCrossCert,
pub signing_key: PublicKey,
pub ipv4_policy: AddrPolicy,
pub ipv6_policy: Intern<PortPolicy>,
pub overload_general: Option<OverloadGeneral>,
pub contact: Option<ContactInfo>,
pub family: Intern<RelayFamily>,
pub family_cert: RetainedOrderVec<EmbeddedCert<Ed25519FamilyCert, KeyUnknownCert>>,
pub caches_extra_info: Option<ItemPresent<CachesExtraInfoToken>>,
pub extra_info_digest: Option<ExtraInfoDigests>,
pub hidden_service_dir: Option<ItemPresent<HiddenServiceDirToken>>,
pub or_address: Vec<SocketAddr>,
pub tunnelled_dir_server: Option<ItemPresent<TunnelledDirServerToken>>,
pub proto: Protocols,
}Expand description
Information about a relay, parsed from a router descriptor.
This type does not hold all the information in the router descriptor
Limitations
See module documentation.
Additionally, some fields that from router descriptors are not yet parsed: see the comments in ROUTER_BODY_RULES for information about those.
Before using this type to connect to a relay, you MUST check that it is valid, using is_expired_at().
Specification
https://spec.torproject.org/dir-spec/server-descriptor-format.html
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.router: RouterDescIntroItemrouter — Introduce a router descriptor.
router <nickname> <address> <orport> <socksport> <dirport>- At start, exactly once.
identity_ed25519: EmbeddedCert<Ed25519IdentityCert, KeyUnknownCert>identity-ed25519 — Specify the router’s ed25519 identity.
https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:identity-ed25519
master_key_ed25519: Ed25519Publicmaster-key-ed25519 — Redundantly specify the router’s ed25519 identity.
master-key-ed25519 <master key>- Exactly once.
bandwidth: Bandwidthbandwidth — Report router’s network bandwidth.
bandwidth <average> <burst> <observed>- Exactly once.
platform: Option<RelayPlatform>platform — Describe the platform on which this relay is running.
platform <rest of line>- At most once.
published: Iso8601TimeSppublished — Time this descriptor (and extra-info) was generated.
published <date> <time>- Exactly once.
fingerprint: Option<SpFingerprint>fingerprint — Redundant hash of ASN-1 encoding of router identity key.
fingerprint <spaced fingerprint>- At most once.
hibernating: NumericBooleanhibernating — Whether the relay is hibernating.
https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:hibernating
uptime: Option<u64>uptime — How long this relay has been continously running
uptime <number>- At most once.
onion_key: Option<PublicKey>onion-key — Relay’s obsolete RSA tap key.
onion-key\n<rsa public key>- At most once.
- No extra arguments.
ntor_onion_key: Curve25519Publicntor-onion-key — The circuit extension key.
ntor-onion-key <base64 padded key>- Exactly once.
ntor_onion_key_crosscert: NtorOnionKeyCrossCertntor-onion-key-crosscert — Reverse cert by K_ntor on KP_relayid_ed
https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:ntor-onion-key-crosscert
signing_key: PublicKeysigning-key — Obsolete RSA identity key.
signing-key\n<rsa public key>
ipv4_policy: AddrPolicyaccept, reject — Exit policy.
accept exitpatternreject exitpattern- Any number of times.
ipv6_policy: Intern<PortPolicy>ipv6-policy — Exit plicy summary for IPv6
ipv6-policy <accept/reject> PortList- At most once.
overload_general: Option<OverloadGeneral>overload-general — Relay is overloaded.
overload-general 1 <time>- At most once.
contact: Option<ContactInfo>contact — Server administrator contact information.
https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:contact
family: Intern<RelayFamily>family — Group relays for the purpose of path selection.
family <LongIdent> ...- One or more
LongIdentarguments. - At most once.
family_cert: RetainedOrderVec<EmbeddedCert<Ed25519FamilyCert, KeyUnknownCert>>family-cert — Prove membership in a relay family.
family-cert\n<object>- Any number of times.
caches_extra_info: Option<ItemPresent<CachesExtraInfoToken>>caches-extra-info — Router provides extra-info as a dirmirror.
caches-extra-info- At most once.
- No extra arguments.
extra_info_digest: Option<ExtraInfoDigests>extra-info-digest — Hash of the extra-info document.
https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:extra-info-digest
hidden-service-dir — Declares this router to be a hidden service directory
https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:hidden-service-dir
or_address: Vec<SocketAddr>or-address — Alternative ORport address and port
https://spec.torproject.org/dir-spec/server-descriptor-format.html#item:or-address
tunnelled_dir_server: Option<ItemPresent<TunnelledDirServerToken>>tunnelled-dir-server — Accepts a BEGIN_DIR relay message.
tunnelled-dir-server- At most once.
- No extra arguments.
proto: Protocolsproto — Subprotocol capabilities supported.
proto <entries>- Exactly once.
Implementations
Sourceimpl RouterDesc
impl RouterDesc
Sourcepub fn rsa_identity(&self) -> RsaIdentity
pub fn rsa_identity(&self) -> RsaIdentity
Return a reference to this relay’s RSA identity.
Sourcepub fn ed_identity(&self) -> &Ed25519Identity
pub fn ed_identity(&self) -> &Ed25519Identity
Return a reference to this relay’s Ed25519 identity.
Sourcepub fn protocols(&self) -> &Protocols
pub fn protocols(&self) -> &Protocols
Return a reference to the list of subprotocol versions supported by this relay.
Sourcepub fn ntor_onion_key(&self) -> &PublicKey
pub fn ntor_onion_key(&self) -> &PublicKey
Return a reference to this relay’s Ntor onion key.
Sourcepub fn published(&self) -> SystemTime
pub fn published(&self) -> SystemTime
Return the publication
Sourcepub fn or_ports(&self) -> impl Iterator<Item = SocketAddr> + '_
pub fn or_ports(&self) -> impl Iterator<Item = SocketAddr> + '_
Return an iterator of every SocketAddr at which this descriptor says
its relay can be reached.
Sourcepub fn family(&self) -> Intern<RelayFamily>
pub fn family(&self) -> Intern<RelayFamily>
Return the declared family of this descriptor.
Sourcepub fn family_ids(&self) -> RelayFamilyIds
pub fn family_ids(&self) -> RelayFamilyIds
Return the authenticated family IDs of this descriptor.
Sourcepub fn parse(s: &str) -> Result<UncheckedRouterDesc>
pub fn parse(s: &str) -> Result<UncheckedRouterDesc>
Try to parse s as a router descriptor.
Does not actually check liveness or signatures; you need to do that yourself before you can do the output.
The following fields are not parsed with the legacy parser and their default value is used instead.