pub trait OptionalityMethods: Copy + Sized {
type Each: Sized + 'static;
type Field: Sized;
// Required method
fn as_option<'f>(self, f: &'f Self::Field) -> Option<&'f Self::Each>;
}Expand description
Methods for handling optionality of a netdoc Object, during encoding
For use by macros.
Each impl allows us to visit an optional element.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.