macro_rules! derive_deftly_module_NetdocSomeItemsParseableCommon {
(
via_modules[{ $($our_opts:tt)* } $next_macro:path { $($next_opts:tt)*
} $($rest:tt)*] { $($predefs:tt)* } { $($main:tt)* } ($($extra:tt)*)
$($ignored:tt)*
) => { ... };
($($wrong:tt)*) => { ... };
}Expand description
Common definitions for NetdocParseable, NetdocParseableFields,
and NetdocParseableSignatures
The including macro is expected to define:
-
THIS_ITEM: consumes the next item and evaluates to it as anUnparsedItem. See the definition inNetdocParseable. -
F_ACCUMULATE_VARthe variable or field into which to accumulate normal items for this field. Must be of type&mut $F_ACCUMULATE_TYPE.
Importer must also import NetdocSomeItemsDeriveCommon and NetdocDeriveAnyCommon.
This is a derive_deftly reuseable template code module.
Do not invoke it directly.