RouterMd

Type Alias RouterMd 

pub type RouterMd = MdRouterStatus;
The real router status entry type.

Aliased Type

pub struct RouterMd {
    pub r: RouterStatusIntroItem,
    pub m: [u8; 32],
    pub a: Vec<SocketAddr>,
    pub flags: DocRelayFlags,
    pub version: Option<SoftwareVersion>,
    pub protos: Protocols,
    pub weight: RelayWeight,
}

Fields

r: RouterStatusIntroItem

r — Introduce a routerstatus entry

https://spec.torproject.org/dir-spec/consensus-formats.html#item:r (and, the md version, which is different).

m: [u8; 32]

m — Microdescriptor or document digest

In an md consensus, the hash of the document for this relay. In a vote, microdescriptor hashes for the various consensus methods.

https://spec.torproject.org/dir-spec/computing-consensus.html#flavor:microdesc r item.

a: Vec<SocketAddr>

a — Further router address(es) (IPv6)

https://spec.torproject.org/dir-spec/consensus-formats.html#item:a (and, the md version, which is different).

flags: DocRelayFlagsversion: Option<SoftwareVersion>protos: Protocolsweight: RelayWeight