pub type RouterVote = VoteRouterStatus;Expand description
The real router status entry type.
Aliased Type
pub struct RouterVote {
pub r: RouterStatusIntroItem,
pub m: Vec<RouterStatusMdDigestsVote>,
pub a: Vec<SocketAddr>,
pub flags: DocRelayFlags,
pub version: Option<SoftwareVersion>,
pub protos: Protocols,
pub weight: RelayWeightsItem,
pub port_policy: Option<Arc<PortPolicy>>,
pub ed25519_id: Ed25519IdentityLine,
pub stats: NetParams<F64Finite>,
}Fields
r: RouterStatusIntroItemr — Introduce a routerstatus entry
https://spec.torproject.org/dir-spec/consensus-formats.html#item:r (and, the md version, which is different).
m: Vec<RouterStatusMdDigestsVote>m — Microdescriptor or document digest
In an md consensus, the hash of the document for this relay. In a vote, microdescriptor hashes for the various consensus methods.
https://spec.torproject.org/dir-spec/computing-consensus.html#flavor:microdesc
r item.
a: Vec<SocketAddr>a — Further router address(es) (IPv6)
https://spec.torproject.org/dir-spec/consensus-formats.html#item:a (and, the md version, which is different).
flags: DocRelayFlagss — Router status flags
https://spec.torproject.org/dir-spec/consensus-formats.html#item:s
version: Option<SoftwareVersion>v — Relay’s Tor software version
https://spec.torproject.org/dir-spec/consensus-formats.html#item:v
protos: Protocolspr — Subprotocol capabilities supported
https://spec.torproject.org/dir-spec/consensus-formats.html#item:v
weight: RelayWeightsItemw — Bandwidth estimates
https://spec.torproject.org/dir-spec/consensus-formats.html#item:w
port_policy: Option<Arc<PortPolicy>>p — Exit ports summary
https://spec.torproject.org/dir-spec/consensus-formats.html#item:p
This field is not properly parsed in plain consensuses by the old parser.
ed25519_id: Ed25519IdentityLineid — Relay’s (ed25519) identity
https://spec.torproject.org/dir-spec/consensus-formats.html#item:id
stats: NetParams<F64Finite>stats – Statistics for this relay
https://spec.torproject.org/dir-spec/consensus-formats.html#item:stats