pub struct SignedDocumentBody<'s> {
pub(crate) body: &'s str,
}Expand description
The part of a network document before the first signature item
This is used for both Orderly signatures where the hash does not contain any part of the signature Item nor of any further signatures. and Disorderly signatures where the hash contains part of the signature Item. (The Tor protocols currently only have Disorderly signatures.)
See “Signature item ordering, and signatures covering signatures”
in the NetdocParseableSignatures derive
and https://gitlab.torproject.org/tpo/core/torspec/-/issues/322.
Fields
body: &'s strThe actual body as a string
Implementations
Sourceimpl<'s> SignedDocumentBody<'s>
impl<'s> SignedDocumentBody<'s>
Sourcepub fn body(&self) -> &'s str
pub fn body(&self) -> &'s str
Method returning copy of SignedDocumentBody::body field.
The actual body as a string