pub trait HasUnverifiedParsedBody {
type UnverifiedParsedBody: NetdocParseable;
// Required method
fn unverified_into_inner_unchecked(
unverified: Self::UnverifiedParsedBody,
) -> Self;
}Expand description
Network document that has an unparsed body type (internal trait)
This is used internally by the
NetdocParseableUnverified derive.
Required Associated Types
Sourcetype UnverifiedParsedBody: NetdocParseable
type UnverifiedParsedBody: NetdocParseable
The actual body payload.
Required Methods
Sourcefn unverified_into_inner_unchecked(
unverified: Self::UnverifiedParsedBody,
) -> Self
fn unverified_into_inner_unchecked( unverified: Self::UnverifiedParsedBody, ) -> Self
Extract the payload
Security hazard
The signature has not been verified, so the returned data must not be trusted.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.