pub struct RelayFamily(Vec<LongIdent>);Expand description
Information about a relay family.
Tor relays may declare that they belong to the same family, to indicate that they are controlled by the same party or parties, and as such should not be used in the same circuit. Two relays belong to the same family if and only if each one lists the other as belonging to its family.
NOTE: when parsing, this type always discards incorrectly-formatted entries, including entries that are only nicknames.
TODO: This type probably belongs in a different crate.
Tuple Fields
0: Vec<LongIdent>Implementations
Sourceimpl RelayFamily
impl RelayFamily
Sourcepub fn push(&mut self, rsa_id: RsaIdentity)
pub fn push(&mut self, rsa_id: RsaIdentity)
Add rsa_id to this family.
Sourcefn normalize(&mut self)
fn normalize(&mut self)
Convert this family to a standard format (with all IDs sorted and de-duplicated).
Sourcepub fn intern(self) -> Arc<Self> ⓘ
pub fn intern(self) -> Arc<Self> ⓘ
Consume this family, and return a new canonical interned representation of the family.
Sourcepub fn contains(&self, rsa_id: &RsaIdentity) -> bool
pub fn contains(&self, rsa_id: &RsaIdentity) -> bool
Does this family include the given relay?
Sourcepub fn members(&self) -> impl Iterator<Item = &RsaIdentity>
pub fn members(&self) -> impl Iterator<Item = &RsaIdentity>
Return an iterator over the RSA identity keys listed in this family.