pub struct AddrPolicy {
rules: Vec<AddrPolicyRule>,
}Expand description
A sequence of rules that are applied to an address:port until one matches.
Each rule is of the form “accept PATTERN” or “reject PATTERN”, where every pattern describes a set of addresses and ports. Address sets are given as a prefix of 0-128 bits that the address must have; port sets are given as a low-bound and high-bound that the target port might lie between.
Relays use this type for defining their own policies, and for publishing their IPv4 policies. Clients instead use super::portpolicy::PortPolicy objects to view a summary of the relays’ declared policies.
An example IPv4 policy might be:
reject *:25
reject 127.0.0.0/8:*
reject 192.168.0.0/16:*
accept *:80
accept *:443
accept *:9000-65535
reject *:*Fields
rules: Vec<AddrPolicyRule>A list of rules to apply to find out whether an address is contained by this policy.
The rules apply in order; the first one to match determines whether the address is accepted or rejected.
Implementations
Sourceimpl AddrPolicy
impl AddrPolicy
Sourcepub fn allows(&self, addr: &IpAddr, port: u16) -> Option<RuleKind>
pub fn allows(&self, addr: &IpAddr, port: u16) -> Option<RuleKind>
Apply this policy to an address:port combination
We do this by applying each rule in sequence, until one matches.
Returns None if no rule matches.
Sourcepub fn allows_sockaddr(&self, addr: &SocketAddr) -> Option<RuleKind>
pub fn allows_sockaddr(&self, addr: &SocketAddr) -> Option<RuleKind>
As allows, but accept a SocketAddr.
Sourcepub fn push(&mut self, kind: RuleKind, pattern: AddrPortPattern)
pub fn push(&mut self, kind: RuleKind, pattern: AddrPortPattern)
Add a new rule to this policy.
The newly added rule is applied after all previous rules. It matches all addresses and ports covered by AddrPortPattern.
If accept is true, the rule is to accept addresses that match; if accept is false, the rule rejects such addresses.