PortPolicy

Struct PortPolicy 

pub struct PortPolicy {
    allowed: PortRanges,
}
A policy to match zero or more TCP/UDP ports.

These are used in Tor to summarize all policies in microdescriptors, and Ipv6 policies in router descriptors.

NOTE: If a port is listed as accepted, it doesn’t mean that the relay allows every address on that port. Instead, a port is listed if a relay will exit to most public addresses on that port. Therefore, unlike super::addrpolicy::AddrPolicy objects, these policies cannot tell you if a port is definitely allowed or rejected: only if it is probably allowed or rejected.

Examples

use tor_netdoc::types::policy::PortPolicy;
let policy: PortPolicy = "accept 1-1023,8000-8999,60000-65535".parse().unwrap();

assert!(policy.allows_port(22));
assert!(policy.allows_port(8000));
assert!(! policy.allows_port(1024));
assert!(! policy.allows_port(9000));

Fields

allowed: PortRanges

A list of port ranges that this policy allows.

In case we see a reject, we simply invert the policy by the assumption that allows policies take less space than reject ones.

Implementations

Source

impl PortPolicy

pub fn new_reject_all() -> Self

Return a new PortPolicy that rejects all ports.

pub fn from_allowed_port_list(ports: Vec<u16>) -> Self

Create a PortPolicy from a list of allowed ports. All other ports will be rejected. The ports in the list may be in any order.

pub fn allows_port(&self, port: u16) -> bool

Return true iff port is allowed by this policy.

pub fn intern(self) -> Arc<Self>

Replace this PortPolicy with an interned copy, to save memory.

pub fn allows_some_port(&self) -> bool

Return true if this policy allows any ports at all.

Example
use tor_netdoc::types::policy::PortPolicy;

let policy: PortPolicy = "accept 22".parse().unwrap();
assert!(policy.allows_some_port());
let policy2: PortPolicy = "reject 1-65535".parse().unwrap();
assert!(! policy2.allows_some_port());