PortRange

Struct PortRange 

pub struct PortRange {
    lo: u16,
    hi: u16,
}
A PortRange is a set of consecutively numbered TCP or UDP ports.

Example

use tor_netdoc::types::policy::PortRange;

let r: PortRange = "22-8000".parse().unwrap();
assert!(r.contains(128));
assert!(r.contains(22));
assert!(r.contains(8000));

assert!(! r.contains(21));
assert!(! r.contains(8001));

Fields

lo: u16

The first port in this range.

hi: u16

The last port in this range.

Implementations

Source

impl PortRange

fn new_unchecked(lo: u16, hi: u16) -> Self

Create a new port range spanning from lo to hi, asserting that the correct invariants hold.

pub fn new_all() -> Self

Create a port range containing all ports.

pub fn new(lo: u16, hi: u16) -> Option<Self>

Create a new PortRange.

The Portrange contains all ports between lo and hi inclusive.

Returns None if lo is greater than hi, or if either is zero.

pub fn contains(&self, port: u16) -> bool

Return true if a port is in this range.

pub fn is_all(&self) -> bool

Return true if this range contains all ports.

fn compare_to_port(&self, port: u16) -> Ordering

Helper for binary search: compare this range to a port.

This range is “equal” to all ports that it contains. It is “greater” than all ports that precede its starting point, and “less” than all ports that follow its ending point.