struct PortRanges(Vec<PortRange>);Expand description
A collection of port ranges in a sorted order.
Please use this when storing multiple port ranges because it optimizies them storage wise.
Tuple Fields
0: Vec<PortRange>Implementations
Sourceimpl PortRanges
impl PortRanges
Sourcefn new() -> Self
fn new() -> Self
Creates a new PortRanges collection with no elements in it.
Sourcefn push_ordered(&mut self, item: PortRange) -> Result<(), PolicyError>
fn push_ordered(&mut self, item: PortRange) -> Result<(), PolicyError>
Adds a new range into this PortRanges.
The ranges must be valid, nonoverlapping, and pushed in a monotonically increasing order,
meaning that inserting 400-500,450-600 or 400-500,500-600 are
invalid, whereas 400-500,501-600 and 400-500,501-600 are.
Sourcefn contains(&self, port: u16) -> bool
fn contains(&self, port: u16) -> bool
Checks whether port is contained in a range.
Whether this means if port is allowed or rejected depends on the
surroundings (such as which field this PortRage is in,
or an associated RuleKind).
Sourcefn invert(&mut self)
fn invert(&mut self)
Inverts a PortRanges.
For example, a PortRanges of 80-443 would become 1-79,444-65535.
Sourcefn iter(&self) -> impl Iterator<Item = &PortRange>
fn iter(&self) -> impl Iterator<Item = &PortRange>
Returns an iterator for PortRanges.