macro_rules! tprintln {
{ $($a:tt)* } => { ... };
}Expand description
eprintln but in tests only, and prefix with "TPRINT "
Called in the non-test code in various places, but elided other than actually in tests.
macro_rules! tprintln {
{ $($a:tt)* } => { ... };
}eprintln but in tests only, and prefix with "TPRINT "
Called in the non-test code in various places, but elided other than actually in tests.