pub struct Ed25519IdentityCert {
pub id_ed25519: Ed25519Identity,
pub sign_ed25519: Ed25519Identity,
}Expand description
An Ed25519 identity certificate.
This is a certificate of CertType::IDENTITY_V_SIGNING where the
relay’s long-term ed25519 identity key signs the relay’s medium-term
ed25519 signing key, used for signing almost all other certifications
associated with a given relay.
Fields
id_ed25519: Ed25519IdentityThe long-term ed25519 identity key of the relay
sign_ed25519: Ed25519IdentityThe medium-term ed25519 signing key of the relay.
Implementations
Sourceimpl Ed25519IdentityCert
impl Ed25519IdentityCert
Sourcepub fn verify(
cert: KeyUnknownCert,
post_tolerance: Duration,
now: SystemTime,
) -> StdResult<Self, VerifyFailed>
pub fn verify( cert: KeyUnknownCert, post_tolerance: Duration, now: SystemTime, ) -> StdResult<Self, VerifyFailed>
Verifies the validity of an Ed25519IdentityCert.
Requirements
- MUST have the identity key in the
signed-with-ed25519-keyextension. - MUST have a valid signature by the identity key.
- MUST be valid at
now. - MUST be of
CertType::IDENTITY_V_SIGNING. - Certified key MUST BE of
tor_cert::CertifiedKey::Ed25519. - Both keys MUST be different.
- Both keys MUST be valid mappings to a
ed25519::PublicKey.
Sourcepub fn new_signed(
id_ed25519: &Keypair,
sign_ed25519: Ed25519Identity,
expiry: SystemTime,
) -> StdResult<EmbeddedCert<Self, KeyUnknownCert>, Bug>
pub fn new_signed( id_ed25519: &Keypair, sign_ed25519: Ed25519Identity, expiry: SystemTime, ) -> StdResult<EmbeddedCert<Self, KeyUnknownCert>, Bug>
Creates a new signed Ed25519IdentityCert.