pub struct IgnoredItemOrObjectValue(Void);Expand description
An Item or Object that would be ignored during parsing and is omitted during encoding
This is the “single” item type for encoding multiplicity for Items or Objects,
for Ignored.
This type is uninhabited.
Tuple Fields
0: VoidTrait Implementations
Sourceimpl ItemValueEncodable for IgnoredItemOrObjectValue
impl ItemValueEncodable for IgnoredItemOrObjectValue
Sourcefn write_item_value_onto(&self, _: ItemEncoder<'_>) -> Result<(), Bug>
fn write_item_value_onto(&self, _: ItemEncoder<'_>) -> Result<(), Bug>
Write the item’s arguments, and any object, onto
out Read moreAuto Trait Implementations
impl Freeze for IgnoredItemOrObjectValue
impl RefUnwindSafe for IgnoredItemOrObjectValue
impl Send for IgnoredItemOrObjectValue
impl Sync for IgnoredItemOrObjectValue
impl Unpin for IgnoredItemOrObjectValue
impl UnsafeUnpin for IgnoredItemOrObjectValue
impl UnwindSafe for IgnoredItemOrObjectValue