#[non_exhaustive]pub struct NotPresentEachValue;Expand description
An individual value that is not present - placeholder type
This is the “single” item type for encoding multiplicity
(for Items, Arguments or Objects), for NotPresent.
It should not be used directly.
During parsing, each “not present” item is ignored,
but the multiplicity arrangements involve parsing each value
and then passing the item value to ItemSetMethods::accumulate
where (for NotPresentEachValue) it is discarded.
Therefore this type must be inhabited; the item parser discards the unparsed item.
During parsing of arguments, parsing is driven by
[our ArgumentSetMethods::parse_with][P2MultiplicitySelector::<NotPresent>::parse_with) which doesn't need to call any parser. So the [ItemArgumentParseable`] implementation always throws an error.
During parsing of objects, rejection is done by
NotPresentEachValue::check_label (and from_bytes).
For encoding, there is only one multiplicity system which
will never call any encoding function, so the encoding functions all throw Bug.
This type has a similar role to IgnoredItemOrObjectValue,
but NotPresentEachValue is different in detail,
and (unlike Ignored) must support arguments, not just items and objects.