pub trait Sealed { }Expand description
A non-exported trait, used to prevent others from implementing a trait.
For more information on this pattern, see the Rust API guidelines.
pub trait Sealed { }A non-exported trait, used to prevent others from implementing a trait.
For more information on this pattern, see the Rust API guidelines.